/* newSliceWindow.c generated by valac 0.56.19, the Vala compiler
 * generated from newSliceWindow.vala, do not modify */

/*///////////////////////////////////////////////////////////////////////*/
/* Copyright 2011-2021 Simon Schneegans*/
/**/
/* Permission is hereby granted, free of charge, to any person obtaining*/
/* a copy of this software and associated documentation files (the*/
/* "Software"), to deal in the Software without restriction, including*/
/* without limitation the rights to use, copy, modify, merge, publish,*/
/* distribute, sublicense, and/or sell copies of the Software, and to*/
/* permit persons to whom the Software is furnished to do so, subject to*/
/* the following conditions:*/
/* */
/* The above copyright notice and this permission notice shall be*/
/* included in all copies or substantial portions of the Software.*/
/* */
/* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,*/
/* EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF*/
/* MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.*/
/* IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY*/
/* CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,*/
/* TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE*/
/* SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.*/
/*///////////////////////////////////////////////////////////////////////*/

#include <glib-object.h>
#include <gtk/gtk.h>
#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include <gee.h>
#include <float.h>
#include <math.h>
#include <gdk/gdk.h>
#include <glib/gi18n-lib.h>
#include <gdk-pixbuf/gdk-pixbuf.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define GNOME_PIE_TYPE_NEW_SLICE_WINDOW (gnome_pie_new_slice_window_get_type ())
#define GNOME_PIE_NEW_SLICE_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_TYPE_NEW_SLICE_WINDOW, GnomePieNewSliceWindow))
#define GNOME_PIE_NEW_SLICE_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_TYPE_NEW_SLICE_WINDOW, GnomePieNewSliceWindowClass))
#define GNOME_PIE_IS_NEW_SLICE_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_TYPE_NEW_SLICE_WINDOW))
#define GNOME_PIE_IS_NEW_SLICE_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_TYPE_NEW_SLICE_WINDOW))
#define GNOME_PIE_NEW_SLICE_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_TYPE_NEW_SLICE_WINDOW, GnomePieNewSliceWindowClass))

typedef struct _GnomePieNewSliceWindow GnomePieNewSliceWindow;
typedef struct _GnomePieNewSliceWindowClass GnomePieNewSliceWindowClass;
typedef struct _GnomePieNewSliceWindowPrivate GnomePieNewSliceWindowPrivate;

#define GNOME_PIE_TYPE_SLICE_TYPE_LIST (gnome_pie_slice_type_list_get_type ())
#define GNOME_PIE_SLICE_TYPE_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_TYPE_SLICE_TYPE_LIST, GnomePieSliceTypeList))
#define GNOME_PIE_SLICE_TYPE_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_TYPE_SLICE_TYPE_LIST, GnomePieSliceTypeListClass))
#define GNOME_PIE_IS_SLICE_TYPE_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_TYPE_SLICE_TYPE_LIST))
#define GNOME_PIE_IS_SLICE_TYPE_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_TYPE_SLICE_TYPE_LIST))
#define GNOME_PIE_SLICE_TYPE_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_TYPE_SLICE_TYPE_LIST, GnomePieSliceTypeListClass))

typedef struct _GnomePieSliceTypeList GnomePieSliceTypeList;
typedef struct _GnomePieSliceTypeListClass GnomePieSliceTypeListClass;

#define GNOME_PIE_TYPE_ICON_SELECT_WINDOW (gnome_pie_icon_select_window_get_type ())
#define GNOME_PIE_ICON_SELECT_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_TYPE_ICON_SELECT_WINDOW, GnomePieIconSelectWindow))
#define GNOME_PIE_ICON_SELECT_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_TYPE_ICON_SELECT_WINDOW, GnomePieIconSelectWindowClass))
#define GNOME_PIE_IS_ICON_SELECT_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_TYPE_ICON_SELECT_WINDOW))
#define GNOME_PIE_IS_ICON_SELECT_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_TYPE_ICON_SELECT_WINDOW))
#define GNOME_PIE_ICON_SELECT_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_TYPE_ICON_SELECT_WINDOW, GnomePieIconSelectWindowClass))

typedef struct _GnomePieIconSelectWindow GnomePieIconSelectWindow;
typedef struct _GnomePieIconSelectWindowClass GnomePieIconSelectWindowClass;

#define GNOME_PIE_TYPE_COMMAND_COMBO_LIST (gnome_pie_command_combo_list_get_type ())
#define GNOME_PIE_COMMAND_COMBO_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_TYPE_COMMAND_COMBO_LIST, GnomePieCommandComboList))
#define GNOME_PIE_COMMAND_COMBO_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_TYPE_COMMAND_COMBO_LIST, GnomePieCommandComboListClass))
#define GNOME_PIE_IS_COMMAND_COMBO_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_TYPE_COMMAND_COMBO_LIST))
#define GNOME_PIE_IS_COMMAND_COMBO_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_TYPE_COMMAND_COMBO_LIST))
#define GNOME_PIE_COMMAND_COMBO_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_TYPE_COMMAND_COMBO_LIST, GnomePieCommandComboListClass))

typedef struct _GnomePieCommandComboList GnomePieCommandComboList;
typedef struct _GnomePieCommandComboListClass GnomePieCommandComboListClass;

#define GNOME_PIE_TYPE_PIE_COMBO_LIST (gnome_pie_pie_combo_list_get_type ())
#define GNOME_PIE_PIE_COMBO_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_TYPE_PIE_COMBO_LIST, GnomePiePieComboList))
#define GNOME_PIE_PIE_COMBO_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_TYPE_PIE_COMBO_LIST, GnomePiePieComboListClass))
#define GNOME_PIE_IS_PIE_COMBO_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_TYPE_PIE_COMBO_LIST))
#define GNOME_PIE_IS_PIE_COMBO_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_TYPE_PIE_COMBO_LIST))
#define GNOME_PIE_PIE_COMBO_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_TYPE_PIE_COMBO_LIST, GnomePiePieComboListClass))

typedef struct _GnomePiePieComboList GnomePiePieComboList;
typedef struct _GnomePiePieComboListClass GnomePiePieComboListClass;

#define GNOME_PIE_TYPE_TRIGGER_SELECT_BUTTON (gnome_pie_trigger_select_button_get_type ())
#define GNOME_PIE_TRIGGER_SELECT_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_TYPE_TRIGGER_SELECT_BUTTON, GnomePieTriggerSelectButton))
#define GNOME_PIE_TRIGGER_SELECT_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_TYPE_TRIGGER_SELECT_BUTTON, GnomePieTriggerSelectButtonClass))
#define GNOME_PIE_IS_TRIGGER_SELECT_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_TYPE_TRIGGER_SELECT_BUTTON))
#define GNOME_PIE_IS_TRIGGER_SELECT_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_TYPE_TRIGGER_SELECT_BUTTON))
#define GNOME_PIE_TRIGGER_SELECT_BUTTON_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_TYPE_TRIGGER_SELECT_BUTTON, GnomePieTriggerSelectButtonClass))

typedef struct _GnomePieTriggerSelectButton GnomePieTriggerSelectButton;
typedef struct _GnomePieTriggerSelectButtonClass GnomePieTriggerSelectButtonClass;
enum  {
	GNOME_PIE_NEW_SLICE_WINDOW_0_PROPERTY,
	GNOME_PIE_NEW_SLICE_WINDOW_NUM_PROPERTIES
};
static GParamSpec* gnome_pie_new_slice_window_properties[GNOME_PIE_NEW_SLICE_WINDOW_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))

#define GNOME_PIE_TYPE_PIE (gnome_pie_pie_get_type ())
#define GNOME_PIE_PIE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_TYPE_PIE, GnomePiePie))
#define GNOME_PIE_PIE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_TYPE_PIE, GnomePiePieClass))
#define GNOME_PIE_IS_PIE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_TYPE_PIE))
#define GNOME_PIE_IS_PIE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_TYPE_PIE))
#define GNOME_PIE_PIE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_TYPE_PIE, GnomePiePieClass))

typedef struct _GnomePiePie GnomePiePie;
typedef struct _GnomePiePieClass GnomePiePieClass;

#define GNOME_PIE_TYPE_TRIGGER (gnome_pie_trigger_get_type ())
#define GNOME_PIE_TRIGGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_TYPE_TRIGGER, GnomePieTrigger))
#define GNOME_PIE_TRIGGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_TYPE_TRIGGER, GnomePieTriggerClass))
#define GNOME_PIE_IS_TRIGGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_TYPE_TRIGGER))
#define GNOME_PIE_IS_TRIGGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_TYPE_TRIGGER))
#define GNOME_PIE_TRIGGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_TYPE_TRIGGER, GnomePieTriggerClass))

typedef struct _GnomePieTrigger GnomePieTrigger;
typedef struct _GnomePieTriggerClass GnomePieTriggerClass;
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

#define GNOME_PIE_TYPE_ACTION_GROUP (gnome_pie_action_group_get_type ())
#define GNOME_PIE_ACTION_GROUP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_TYPE_ACTION_GROUP, GnomePieActionGroup))
#define GNOME_PIE_ACTION_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_TYPE_ACTION_GROUP, GnomePieActionGroupClass))
#define GNOME_PIE_IS_ACTION_GROUP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_TYPE_ACTION_GROUP))
#define GNOME_PIE_IS_ACTION_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_TYPE_ACTION_GROUP))
#define GNOME_PIE_ACTION_GROUP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_TYPE_ACTION_GROUP, GnomePieActionGroupClass))

typedef struct _GnomePieActionGroup GnomePieActionGroup;
typedef struct _GnomePieActionGroupClass GnomePieActionGroupClass;

#define GNOME_PIE_TYPE_ACTION (gnome_pie_action_get_type ())
#define GNOME_PIE_ACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_TYPE_ACTION, GnomePieAction))
#define GNOME_PIE_ACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_TYPE_ACTION, GnomePieActionClass))
#define GNOME_PIE_IS_ACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_TYPE_ACTION))
#define GNOME_PIE_IS_ACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_TYPE_ACTION))
#define GNOME_PIE_ACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_TYPE_ACTION, GnomePieActionClass))

typedef struct _GnomePieAction GnomePieAction;
typedef struct _GnomePieActionClass GnomePieActionClass;

#define GNOME_PIE_ACTION_REGISTRY_TYPE_TYPEDESCRIPTION (gnome_pie_action_registry_typedescription_get_type ())
#define GNOME_PIE_ACTION_REGISTRY_TYPEDESCRIPTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_ACTION_REGISTRY_TYPE_TYPEDESCRIPTION, GnomePieActionRegistryTypeDescription))
#define GNOME_PIE_ACTION_REGISTRY_TYPEDESCRIPTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_ACTION_REGISTRY_TYPE_TYPEDESCRIPTION, GnomePieActionRegistryTypeDescriptionClass))
#define GNOME_PIE_ACTION_REGISTRY_IS_TYPEDESCRIPTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_ACTION_REGISTRY_TYPE_TYPEDESCRIPTION))
#define GNOME_PIE_ACTION_REGISTRY_IS_TYPEDESCRIPTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_ACTION_REGISTRY_TYPE_TYPEDESCRIPTION))
#define GNOME_PIE_ACTION_REGISTRY_TYPEDESCRIPTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_ACTION_REGISTRY_TYPE_TYPEDESCRIPTION, GnomePieActionRegistryTypeDescriptionClass))

typedef struct _GnomePieActionRegistryTypeDescription GnomePieActionRegistryTypeDescription;
typedef struct _GnomePieActionRegistryTypeDescriptionClass GnomePieActionRegistryTypeDescriptionClass;
#define _gnome_pie_action_registry_typedescription_unref0(var) ((var == NULL) ? NULL : (var = (gnome_pie_action_registry_typedescription_unref (var), NULL)))

#define GNOME_PIE_GROUP_REGISTRY_TYPE_TYPEDESCRIPTION (gnome_pie_group_registry_typedescription_get_type ())
#define GNOME_PIE_GROUP_REGISTRY_TYPEDESCRIPTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_GROUP_REGISTRY_TYPE_TYPEDESCRIPTION, GnomePieGroupRegistryTypeDescription))
#define GNOME_PIE_GROUP_REGISTRY_TYPEDESCRIPTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_GROUP_REGISTRY_TYPE_TYPEDESCRIPTION, GnomePieGroupRegistryTypeDescriptionClass))
#define GNOME_PIE_GROUP_REGISTRY_IS_TYPEDESCRIPTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_GROUP_REGISTRY_TYPE_TYPEDESCRIPTION))
#define GNOME_PIE_GROUP_REGISTRY_IS_TYPEDESCRIPTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_GROUP_REGISTRY_TYPE_TYPEDESCRIPTION))
#define GNOME_PIE_GROUP_REGISTRY_TYPEDESCRIPTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_GROUP_REGISTRY_TYPE_TYPEDESCRIPTION, GnomePieGroupRegistryTypeDescriptionClass))

typedef struct _GnomePieGroupRegistryTypeDescription GnomePieGroupRegistryTypeDescription;
typedef struct _GnomePieGroupRegistryTypeDescriptionClass GnomePieGroupRegistryTypeDescriptionClass;
#define _gnome_pie_group_registry_typedescription_unref0(var) ((var == NULL) ? NULL : (var = (gnome_pie_group_registry_typedescription_unref (var), NULL)))

#define GNOME_PIE_TYPE_CLIPBOARD_GROUP (gnome_pie_clipboard_group_get_type ())
#define GNOME_PIE_CLIPBOARD_GROUP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_TYPE_CLIPBOARD_GROUP, GnomePieClipboardGroup))
#define GNOME_PIE_CLIPBOARD_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_TYPE_CLIPBOARD_GROUP, GnomePieClipboardGroupClass))
#define GNOME_PIE_IS_CLIPBOARD_GROUP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_TYPE_CLIPBOARD_GROUP))
#define GNOME_PIE_IS_CLIPBOARD_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_TYPE_CLIPBOARD_GROUP))
#define GNOME_PIE_CLIPBOARD_GROUP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_TYPE_CLIPBOARD_GROUP, GnomePieClipboardGroupClass))

typedef struct _GnomePieClipboardGroup GnomePieClipboardGroup;
typedef struct _GnomePieClipboardGroupClass GnomePieClipboardGroupClass;

#define GNOME_PIE_TYPE_WINDOW_LIST_GROUP (gnome_pie_window_list_group_get_type ())
#define GNOME_PIE_WINDOW_LIST_GROUP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_TYPE_WINDOW_LIST_GROUP, GnomePieWindowListGroup))
#define GNOME_PIE_WINDOW_LIST_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_TYPE_WINDOW_LIST_GROUP, GnomePieWindowListGroupClass))
#define GNOME_PIE_IS_WINDOW_LIST_GROUP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_TYPE_WINDOW_LIST_GROUP))
#define GNOME_PIE_IS_WINDOW_LIST_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_TYPE_WINDOW_LIST_GROUP))
#define GNOME_PIE_WINDOW_LIST_GROUP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_TYPE_WINDOW_LIST_GROUP, GnomePieWindowListGroupClass))

typedef struct _GnomePieWindowListGroup GnomePieWindowListGroup;
typedef struct _GnomePieWindowListGroupClass GnomePieWindowListGroupClass;

#define GNOME_PIE_TYPE_BOOKMARK_GROUP (gnome_pie_bookmark_group_get_type ())
#define GNOME_PIE_BOOKMARK_GROUP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_TYPE_BOOKMARK_GROUP, GnomePieBookmarkGroup))
#define GNOME_PIE_BOOKMARK_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_TYPE_BOOKMARK_GROUP, GnomePieBookmarkGroupClass))
#define GNOME_PIE_IS_BOOKMARK_GROUP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_TYPE_BOOKMARK_GROUP))
#define GNOME_PIE_IS_BOOKMARK_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_TYPE_BOOKMARK_GROUP))
#define GNOME_PIE_BOOKMARK_GROUP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_TYPE_BOOKMARK_GROUP, GnomePieBookmarkGroupClass))

typedef struct _GnomePieBookmarkGroup GnomePieBookmarkGroup;
typedef struct _GnomePieBookmarkGroupClass GnomePieBookmarkGroupClass;

#define GNOME_PIE_TYPE_DEVICES_GROUP (gnome_pie_devices_group_get_type ())
#define GNOME_PIE_DEVICES_GROUP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_TYPE_DEVICES_GROUP, GnomePieDevicesGroup))
#define GNOME_PIE_DEVICES_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_TYPE_DEVICES_GROUP, GnomePieDevicesGroupClass))
#define GNOME_PIE_IS_DEVICES_GROUP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_TYPE_DEVICES_GROUP))
#define GNOME_PIE_IS_DEVICES_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_TYPE_DEVICES_GROUP))
#define GNOME_PIE_DEVICES_GROUP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_TYPE_DEVICES_GROUP, GnomePieDevicesGroupClass))

typedef struct _GnomePieDevicesGroup GnomePieDevicesGroup;
typedef struct _GnomePieDevicesGroupClass GnomePieDevicesGroupClass;

#define GNOME_PIE_TYPE_MENU_GROUP (gnome_pie_menu_group_get_type ())
#define GNOME_PIE_MENU_GROUP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_TYPE_MENU_GROUP, GnomePieMenuGroup))
#define GNOME_PIE_MENU_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_TYPE_MENU_GROUP, GnomePieMenuGroupClass))
#define GNOME_PIE_IS_MENU_GROUP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_TYPE_MENU_GROUP))
#define GNOME_PIE_IS_MENU_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_TYPE_MENU_GROUP))
#define GNOME_PIE_MENU_GROUP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_TYPE_MENU_GROUP, GnomePieMenuGroupClass))

typedef struct _GnomePieMenuGroup GnomePieMenuGroup;
typedef struct _GnomePieMenuGroupClass GnomePieMenuGroupClass;

#define GNOME_PIE_TYPE_SESSION_GROUP (gnome_pie_session_group_get_type ())
#define GNOME_PIE_SESSION_GROUP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_TYPE_SESSION_GROUP, GnomePieSessionGroup))
#define GNOME_PIE_SESSION_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_TYPE_SESSION_GROUP, GnomePieSessionGroupClass))
#define GNOME_PIE_IS_SESSION_GROUP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_TYPE_SESSION_GROUP))
#define GNOME_PIE_IS_SESSION_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_TYPE_SESSION_GROUP))
#define GNOME_PIE_SESSION_GROUP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_TYPE_SESSION_GROUP, GnomePieSessionGroupClass))

typedef struct _GnomePieSessionGroup GnomePieSessionGroup;
typedef struct _GnomePieSessionGroupClass GnomePieSessionGroupClass;

#define GNOME_PIE_TYPE_APP_ACTION (gnome_pie_app_action_get_type ())
#define GNOME_PIE_APP_ACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_TYPE_APP_ACTION, GnomePieAppAction))
#define GNOME_PIE_APP_ACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_TYPE_APP_ACTION, GnomePieAppActionClass))
#define GNOME_PIE_IS_APP_ACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_TYPE_APP_ACTION))
#define GNOME_PIE_IS_APP_ACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_TYPE_APP_ACTION))
#define GNOME_PIE_APP_ACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_TYPE_APP_ACTION, GnomePieAppActionClass))

typedef struct _GnomePieAppAction GnomePieAppAction;
typedef struct _GnomePieAppActionClass GnomePieAppActionClass;

#define GNOME_PIE_TYPE_KEY_ACTION (gnome_pie_key_action_get_type ())
#define GNOME_PIE_KEY_ACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_TYPE_KEY_ACTION, GnomePieKeyAction))
#define GNOME_PIE_KEY_ACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_TYPE_KEY_ACTION, GnomePieKeyActionClass))
#define GNOME_PIE_IS_KEY_ACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_TYPE_KEY_ACTION))
#define GNOME_PIE_IS_KEY_ACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_TYPE_KEY_ACTION))
#define GNOME_PIE_KEY_ACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_TYPE_KEY_ACTION, GnomePieKeyActionClass))

typedef struct _GnomePieKeyAction GnomePieKeyAction;
typedef struct _GnomePieKeyActionClass GnomePieKeyActionClass;

#define GNOME_PIE_TYPE_PIE_ACTION (gnome_pie_pie_action_get_type ())
#define GNOME_PIE_PIE_ACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_TYPE_PIE_ACTION, GnomePiePieAction))
#define GNOME_PIE_PIE_ACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_TYPE_PIE_ACTION, GnomePiePieActionClass))
#define GNOME_PIE_IS_PIE_ACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_TYPE_PIE_ACTION))
#define GNOME_PIE_IS_PIE_ACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_TYPE_PIE_ACTION))
#define GNOME_PIE_PIE_ACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_TYPE_PIE_ACTION, GnomePiePieActionClass))

typedef struct _GnomePiePieAction GnomePiePieAction;
typedef struct _GnomePiePieActionClass GnomePiePieActionClass;

#define GNOME_PIE_TYPE_URI_ACTION (gnome_pie_uri_action_get_type ())
#define GNOME_PIE_URI_ACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_TYPE_URI_ACTION, GnomePieUriAction))
#define GNOME_PIE_URI_ACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_TYPE_URI_ACTION, GnomePieUriActionClass))
#define GNOME_PIE_IS_URI_ACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_TYPE_URI_ACTION))
#define GNOME_PIE_IS_URI_ACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_TYPE_URI_ACTION))
#define GNOME_PIE_URI_ACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_TYPE_URI_ACTION, GnomePieUriActionClass))

typedef struct _GnomePieUriAction GnomePieUriAction;
typedef struct _GnomePieUriActionClass GnomePieUriActionClass;
enum  {
	GNOME_PIE_NEW_SLICE_WINDOW_ON_SELECT_SIGNAL,
	GNOME_PIE_NEW_SLICE_WINDOW_NUM_SIGNALS
};
static guint gnome_pie_new_slice_window_signals[GNOME_PIE_NEW_SLICE_WINDOW_NUM_SIGNALS] = {0};

struct _GnomePieNewSliceWindow {
	GObject parent_instance;
	GnomePieNewSliceWindowPrivate * priv;
};

struct _GnomePieNewSliceWindowClass {
	GObjectClass parent_class;
};

struct _GnomePieNewSliceWindowPrivate {
	GnomePieSliceTypeList* slice_type_list;
	GnomePieIconSelectWindow* icon_window;
	GtkDialog* window;
	GtkBox* name_box;
	GtkBox* command_box;
	GtkButton* icon_button;
	GtkBox* no_options_box;
	GtkBox* pie_box;
	GtkBox* hotkey_box;
	GtkBox* uri_box;
	GtkBox* quickaction_box;
	GtkBox* clipboard_box;
	GtkBox* workspace_only_box;
	GtkImage* icon;
	GtkEntry* name_entry;
	GnomePieCommandComboList* command_list;
	GtkEntry* uri_entry;
	GtkSwitch* quickaction_checkbutton;
	GtkSwitch* workspace_only_checkbutton;
	GtkScale* clipboard_slider;
	GnomePiePieComboList* pie_select;
	GnomePieTriggerSelectButton* key_select;
	gchar* current_type;
	gchar* current_icon;
	gchar* current_id;
	gchar* current_custom_icon;
	gchar* current_hotkey;
	gchar* current_pie_to_open;
	gint slice_position;
	gboolean add_as_new_slice;
};

static gint GnomePieNewSliceWindow_private_offset;
static gpointer gnome_pie_new_slice_window_parent_class = NULL;

VALA_EXTERN GType gnome_pie_new_slice_window_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePieNewSliceWindow, g_object_unref)
VALA_EXTERN GType gnome_pie_slice_type_list_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePieSliceTypeList, g_object_unref)
VALA_EXTERN GType gnome_pie_icon_select_window_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePieIconSelectWindow, g_object_unref)
VALA_EXTERN GType gnome_pie_command_combo_list_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePieCommandComboList, g_object_unref)
VALA_EXTERN GType gnome_pie_pie_combo_list_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePiePieComboList, g_object_unref)
VALA_EXTERN GType gnome_pie_trigger_select_button_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePieTriggerSelectButton, g_object_unref)
VALA_EXTERN GnomePieNewSliceWindow* gnome_pie_new_slice_window_new (void);
VALA_EXTERN GnomePieNewSliceWindow* gnome_pie_new_slice_window_construct (GType object_type);
VALA_EXTERN const gchar* gnome_pie_paths_get_ui_files (void);
VALA_EXTERN GnomePieSliceTypeList* gnome_pie_slice_type_list_new (void);
VALA_EXTERN GnomePieSliceTypeList* gnome_pie_slice_type_list_construct (GType object_type);
static void ___lambda55_ (GnomePieNewSliceWindow* self,
                   const gchar* type,
                   const gchar* icon);
static void gnome_pie_new_slice_window_set_icon (GnomePieNewSliceWindow* self,
                                          const gchar* icon);
VALA_EXTERN GType gnome_pie_pie_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePiePie, g_object_unref)
VALA_EXTERN GeeHashMap* gnome_pie_pie_manager_get_all_pies (void);
VALA_EXTERN const gchar* gnome_pie_pie_combo_list_get_current_id (GnomePiePieComboList* self);
VALA_EXTERN const gchar* gnome_pie_pie_get_icon (GnomePiePie* self);
static void ____lambda55__gnome_pie_slice_type_list_on_select (GnomePieSliceTypeList* _sender,
                                                        const gchar* id,
                                                        const gchar* icon_name,
                                                        gpointer self);
VALA_EXTERN GnomePiePieComboList* gnome_pie_pie_combo_list_new (void);
VALA_EXTERN GnomePiePieComboList* gnome_pie_pie_combo_list_construct (GType object_type);
static void ___lambda56_ (GnomePieNewSliceWindow* self,
                   const gchar* id);
static void ____lambda56__gnome_pie_pie_combo_list_on_select (GnomePiePieComboList* _sender,
                                                       const gchar* id,
                                                       gpointer self);
VALA_EXTERN GnomePieTriggerSelectButton* gnome_pie_trigger_select_button_new (gboolean enable_mouse);
VALA_EXTERN GnomePieTriggerSelectButton* gnome_pie_trigger_select_button_construct (GType object_type,
                                                                        gboolean enable_mouse);
VALA_EXTERN GType gnome_pie_trigger_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePieTrigger, g_object_unref)
static void ___lambda57_ (GnomePieNewSliceWindow* self,
                   GnomePieTrigger* trigger);
VALA_EXTERN const gchar* gnome_pie_trigger_get_name (GnomePieTrigger* self);
static void ____lambda57__gnome_pie_trigger_select_button_on_select (GnomePieTriggerSelectButton* _sender,
                                                              GnomePieTrigger* trigger,
                                                              gpointer self);
VALA_EXTERN GnomePieCommandComboList* gnome_pie_command_combo_list_new (void);
VALA_EXTERN GnomePieCommandComboList* gnome_pie_command_combo_list_construct (GType object_type);
static void ___lambda58_ (GnomePieNewSliceWindow* self,
                   const gchar* name,
                   const gchar* command,
                   const gchar* icon);
static void ____lambda58__gnome_pie_command_combo_list_on_select (GnomePieCommandComboList* _sender,
                                                           const gchar* name,
                                                           const gchar* command,
                                                           const gchar* icon,
                                                           gpointer self);
static void gnome_pie_new_slice_window_on_icon_button_clicked (GnomePieNewSliceWindow* self,
                                                        GtkButton* button);
static void _gnome_pie_new_slice_window_on_icon_button_clicked_gtk_button_clicked (GtkButton* _sender,
                                                                            gpointer self);
static void gnome_pie_new_slice_window_on_ok_button_clicked (GnomePieNewSliceWindow* self);
static void _gnome_pie_new_slice_window_on_ok_button_clicked_gtk_button_clicked (GtkButton* _sender,
                                                                          gpointer self);
static void gnome_pie_new_slice_window_on_cancel_button_clicked (GnomePieNewSliceWindow* self);
static void _gnome_pie_new_slice_window_on_cancel_button_clicked_gtk_button_clicked (GtkButton* _sender,
                                                                              gpointer self);
static gboolean _gtk_widget_hide_on_delete_gtk_widget_delete_event (GtkWidget* _sender,
                                                             GdkEventAny* event,
                                                             gpointer self);
VALA_EXTERN void gnome_pie_new_slice_window_set_parent (GnomePieNewSliceWindow* self,
                                            GtkWindow* parent);
VALA_EXTERN void gnome_pie_new_slice_window_show (GnomePieNewSliceWindow* self);
VALA_EXTERN void gnome_pie_slice_type_list_select_first (GnomePieSliceTypeList* self);
VALA_EXTERN void gnome_pie_pie_combo_list_select_first (GnomePiePieComboList* self);
VALA_EXTERN void gnome_pie_trigger_select_button_set_trigger (GnomePieTriggerSelectButton* self,
                                                  GnomePieTrigger* trigger);
VALA_EXTERN GnomePieTrigger* gnome_pie_trigger_new (void);
VALA_EXTERN GnomePieTrigger* gnome_pie_trigger_construct (GType object_type);
VALA_EXTERN void gnome_pie_new_slice_window_reload (GnomePieNewSliceWindow* self);
VALA_EXTERN void gnome_pie_pie_combo_list_reload (GnomePiePieComboList* self);
VALA_EXTERN GType gnome_pie_action_group_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePieActionGroup, g_object_unref)
VALA_EXTERN void gnome_pie_new_slice_window_set_action (GnomePieNewSliceWindow* self,
                                            GnomePieActionGroup* group,
                                            gint position);
VALA_EXTERN void gnome_pie_new_slice_window_set_default (GnomePieNewSliceWindow* self,
                                             const gchar* pie_id,
                                             gint position);
VALA_EXTERN const gchar* gnome_pie_action_group_get_parent_id (GnomePieActionGroup* self);
VALA_EXTERN GType gnome_pie_action_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePieAction, g_object_unref)
VALA_EXTERN GeeArrayList* gnome_pie_action_group_get_actions (GnomePieActionGroup* self);
VALA_EXTERN gpointer gnome_pie_action_registry_typedescription_ref (gpointer instance);
VALA_EXTERN void gnome_pie_action_registry_typedescription_unref (gpointer instance);
VALA_EXTERN GParamSpec* gnome_pie_action_registry_param_spec_typedescription (const gchar* name,
                                                                  const gchar* nick,
                                                                  const gchar* blurb,
                                                                  GType object_type,
                                                                  GParamFlags flags);
VALA_EXTERN void gnome_pie_action_registry_value_set_typedescription (GValue* value,
                                                          gpointer v_object);
VALA_EXTERN void gnome_pie_action_registry_value_take_typedescription (GValue* value,
                                                           gpointer v_object);
VALA_EXTERN gpointer gnome_pie_action_registry_value_get_typedescription (const GValue* value);
VALA_EXTERN GType gnome_pie_action_registry_typedescription_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePieActionRegistryTypeDescription, gnome_pie_action_registry_typedescription_unref)
VALA_EXTERN GeeHashMap* gnome_pie_action_registry_get_descriptions (void);
VALA_EXTERN const gchar* gnome_pie_action_registry_typedescription_get_id (GnomePieActionRegistryTypeDescription* self);
static void gnome_pie_new_slice_window_select_type (GnomePieNewSliceWindow* self,
                                             const gchar* type);
VALA_EXTERN const gchar* gnome_pie_action_get_icon (GnomePieAction* self);
VALA_EXTERN gboolean gnome_pie_action_get_is_quickaction (GnomePieAction* self);
VALA_EXTERN const gchar* gnome_pie_action_get_name (GnomePieAction* self);
VALA_EXTERN const gchar* gnome_pie_action_get_real_command (GnomePieAction* self);
VALA_EXTERN void gnome_pie_command_combo_list_set_text (GnomePieCommandComboList* self,
                                            const gchar* value);
VALA_EXTERN GnomePieTrigger* gnome_pie_trigger_new_from_string (const gchar* trigger);
VALA_EXTERN GnomePieTrigger* gnome_pie_trigger_construct_from_string (GType object_type,
                                                          const gchar* trigger);
VALA_EXTERN void gnome_pie_pie_combo_list_select (GnomePiePieComboList* self,
                                      const gchar* id);
VALA_EXTERN gpointer gnome_pie_group_registry_typedescription_ref (gpointer instance);
VALA_EXTERN void gnome_pie_group_registry_typedescription_unref (gpointer instance);
VALA_EXTERN GParamSpec* gnome_pie_group_registry_param_spec_typedescription (const gchar* name,
                                                                 const gchar* nick,
                                                                 const gchar* blurb,
                                                                 GType object_type,
                                                                 GParamFlags flags);
VALA_EXTERN void gnome_pie_group_registry_value_set_typedescription (GValue* value,
                                                         gpointer v_object);
VALA_EXTERN void gnome_pie_group_registry_value_take_typedescription (GValue* value,
                                                          gpointer v_object);
VALA_EXTERN gpointer gnome_pie_group_registry_value_get_typedescription (const GValue* value);
VALA_EXTERN GType gnome_pie_group_registry_typedescription_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePieGroupRegistryTypeDescription, gnome_pie_group_registry_typedescription_unref)
VALA_EXTERN GeeHashMap* gnome_pie_group_registry_get_descriptions (void);
VALA_EXTERN const gchar* gnome_pie_group_registry_typedescription_get_id (GnomePieGroupRegistryTypeDescription* self);
VALA_EXTERN GType gnome_pie_clipboard_group_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePieClipboardGroup, g_object_unref)
VALA_EXTERN gint gnome_pie_clipboard_group_get_max_items (GnomePieClipboardGroup* self);
VALA_EXTERN GType gnome_pie_window_list_group_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePieWindowListGroup, g_object_unref)
VALA_EXTERN gboolean gnome_pie_window_list_group_get_current_workspace_only (GnomePieWindowListGroup* self);
VALA_EXTERN void gnome_pie_slice_type_list_select (GnomePieSliceTypeList* self,
                                       const gchar* id);
VALA_EXTERN GnomePieBookmarkGroup* gnome_pie_bookmark_group_new (const gchar* parent_id);
VALA_EXTERN GnomePieBookmarkGroup* gnome_pie_bookmark_group_construct (GType object_type,
                                                           const gchar* parent_id);
VALA_EXTERN GType gnome_pie_bookmark_group_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePieBookmarkGroup, g_object_unref)
VALA_EXTERN GnomePieDevicesGroup* gnome_pie_devices_group_new (const gchar* parent_id);
VALA_EXTERN GnomePieDevicesGroup* gnome_pie_devices_group_construct (GType object_type,
                                                         const gchar* parent_id);
VALA_EXTERN GType gnome_pie_devices_group_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePieDevicesGroup, g_object_unref)
VALA_EXTERN GnomePieMenuGroup* gnome_pie_menu_group_new (const gchar* parent_id);
VALA_EXTERN GnomePieMenuGroup* gnome_pie_menu_group_construct (GType object_type,
                                                   const gchar* parent_id);
VALA_EXTERN GType gnome_pie_menu_group_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePieMenuGroup, g_object_unref)
VALA_EXTERN GnomePieSessionGroup* gnome_pie_session_group_new (const gchar* parent_id);
VALA_EXTERN GnomePieSessionGroup* gnome_pie_session_group_construct (GType object_type,
                                                         const gchar* parent_id);
VALA_EXTERN GType gnome_pie_session_group_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePieSessionGroup, g_object_unref)
VALA_EXTERN GnomePieClipboardGroup* gnome_pie_clipboard_group_new (const gchar* parent_id);
VALA_EXTERN GnomePieClipboardGroup* gnome_pie_clipboard_group_construct (GType object_type,
                                                             const gchar* parent_id);
VALA_EXTERN void gnome_pie_clipboard_group_set_max_items (GnomePieClipboardGroup* self,
                                              gint value);
VALA_EXTERN GnomePieWindowListGroup* gnome_pie_window_list_group_new (const gchar* parent_id);
VALA_EXTERN GnomePieWindowListGroup* gnome_pie_window_list_group_construct (GType object_type,
                                                                const gchar* parent_id);
VALA_EXTERN void gnome_pie_window_list_group_set_current_workspace_only (GnomePieWindowListGroup* self,
                                                             gboolean value);
VALA_EXTERN GnomePieActionGroup* gnome_pie_action_group_new (const gchar* parent_id);
VALA_EXTERN GnomePieActionGroup* gnome_pie_action_group_construct (GType object_type,
                                                       const gchar* parent_id);
VALA_EXTERN void gnome_pie_action_group_add_action (GnomePieActionGroup* self,
                                        GnomePieAction* new_action);
VALA_EXTERN const gchar* gnome_pie_command_combo_list_get_text (GnomePieCommandComboList* self);
VALA_EXTERN GnomePieAppAction* gnome_pie_app_action_new (const gchar* name,
                                             const gchar* icon,
                                             const gchar* command,
                                             gboolean is_quickaction);
VALA_EXTERN GnomePieAppAction* gnome_pie_app_action_construct (GType object_type,
                                                   const gchar* name,
                                                   const gchar* icon,
                                                   const gchar* command,
                                                   gboolean is_quickaction);
VALA_EXTERN GType gnome_pie_app_action_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePieAppAction, g_object_unref)
VALA_EXTERN GnomePieKeyAction* gnome_pie_key_action_new (const gchar* name,
                                             const gchar* icon,
                                             const gchar* command,
                                             gboolean is_quickaction);
VALA_EXTERN GnomePieKeyAction* gnome_pie_key_action_construct (GType object_type,
                                                   const gchar* name,
                                                   const gchar* icon,
                                                   const gchar* command,
                                                   gboolean is_quickaction);
VALA_EXTERN GType gnome_pie_key_action_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePieKeyAction, g_object_unref)
VALA_EXTERN GnomePiePieAction* gnome_pie_pie_action_new (const gchar* id,
                                             gboolean is_quickaction);
VALA_EXTERN GnomePiePieAction* gnome_pie_pie_action_construct (GType object_type,
                                                   const gchar* id,
                                                   gboolean is_quickaction);
VALA_EXTERN GType gnome_pie_pie_action_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePiePieAction, g_object_unref)
VALA_EXTERN GnomePieUriAction* gnome_pie_uri_action_new (const gchar* name,
                                             const gchar* icon,
                                             const gchar* command,
                                             gboolean is_quickaction);
VALA_EXTERN GnomePieUriAction* gnome_pie_uri_action_construct (GType object_type,
                                                   const gchar* name,
                                                   const gchar* icon,
                                                   const gchar* command,
                                                   gboolean is_quickaction);
VALA_EXTERN GType gnome_pie_uri_action_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePieUriAction, g_object_unref)
VALA_EXTERN GnomePieIconSelectWindow* gnome_pie_icon_select_window_new (GtkWindow* parent);
VALA_EXTERN GnomePieIconSelectWindow* gnome_pie_icon_select_window_construct (GType object_type,
                                                                  GtkWindow* parent);
static void ___lambda59_ (GnomePieNewSliceWindow* self,
                   const gchar* icon);
static void ____lambda59__gnome_pie_icon_select_window_on_ok (GnomePieIconSelectWindow* _sender,
                                                       const gchar* icon_name,
                                                       gpointer self);
VALA_EXTERN void gnome_pie_icon_select_window_show (GnomePieIconSelectWindow* self);
VALA_EXTERN void gnome_pie_icon_select_window_set_icon (GnomePieIconSelectWindow* self,
                                            const gchar* icon);
static void g_cclosure_user_marshal_VOID__OBJECT_BOOLEAN_INT (GClosure * closure,
                                                       GValue * return_value,
                                                       guint n_param_values,
                                                       const GValue * param_values,
                                                       gpointer invocation_hint,
                                                       gpointer marshal_data);
static void gnome_pie_new_slice_window_finalize (GObject * obj);
static GType gnome_pie_new_slice_window_get_type_once (void);

static inline gpointer
gnome_pie_new_slice_window_get_instance_private (GnomePieNewSliceWindow* self)
{
	return G_STRUCT_MEMBER_P (self, GnomePieNewSliceWindow_private_offset);
}

static void
___lambda55_ (GnomePieNewSliceWindow* self,
              const gchar* type,
              const gchar* icon)
{
	GtkBox* _tmp0_;
	GtkBox* _tmp1_;
	GtkButton* _tmp2_;
	GtkBox* _tmp3_;
	GtkBox* _tmp4_;
	GtkBox* _tmp5_;
	GtkBox* _tmp6_;
	GtkBox* _tmp7_;
	GtkBox* _tmp8_;
	GtkBox* _tmp9_;
	gchar* _tmp10_;
	const gchar* _tmp11_;
	GQuark _tmp13_ = 0U;
	static GQuark _tmp12_label0 = 0;
	static GQuark _tmp12_label1 = 0;
	static GQuark _tmp12_label2 = 0;
	static GQuark _tmp12_label3 = 0;
	static GQuark _tmp12_label4 = 0;
	static GQuark _tmp12_label5 = 0;
	static GQuark _tmp12_label6 = 0;
	static GQuark _tmp12_label7 = 0;
	static GQuark _tmp12_label8 = 0;
	static GQuark _tmp12_label9 = 0;
	g_return_if_fail (type != NULL);
	g_return_if_fail (icon != NULL);
	_tmp0_ = self->priv->name_box;
	gtk_widget_hide ((GtkWidget*) _tmp0_);
	_tmp1_ = self->priv->command_box;
	gtk_widget_hide ((GtkWidget*) _tmp1_);
	_tmp2_ = self->priv->icon_button;
	gtk_widget_set_sensitive ((GtkWidget*) _tmp2_, FALSE);
	_tmp3_ = self->priv->no_options_box;
	gtk_widget_hide ((GtkWidget*) _tmp3_);
	_tmp4_ = self->priv->pie_box;
	gtk_widget_hide ((GtkWidget*) _tmp4_);
	_tmp5_ = self->priv->hotkey_box;
	gtk_widget_hide ((GtkWidget*) _tmp5_);
	_tmp6_ = self->priv->uri_box;
	gtk_widget_hide ((GtkWidget*) _tmp6_);
	_tmp7_ = self->priv->quickaction_box;
	gtk_widget_hide ((GtkWidget*) _tmp7_);
	_tmp8_ = self->priv->workspace_only_box;
	gtk_widget_hide ((GtkWidget*) _tmp8_);
	_tmp9_ = self->priv->clipboard_box;
	gtk_widget_hide ((GtkWidget*) _tmp9_);
	_tmp10_ = g_strdup (type);
	_g_free0 (self->priv->current_type);
	self->priv->current_type = _tmp10_;
	_tmp11_ = type;
	_tmp13_ = (NULL == _tmp11_) ? 0 : g_quark_from_string (_tmp11_);
	if ((((_tmp13_ == ((0 != _tmp12_label0) ? _tmp12_label0 : (_tmp12_label0 = g_quark_from_static_string ("bookmarks")))) || (_tmp13_ == ((0 != _tmp12_label1) ? _tmp12_label1 : (_tmp12_label1 = g_quark_from_static_string ("devices"))))) || (_tmp13_ == ((0 != _tmp12_label2) ? _tmp12_label2 : (_tmp12_label2 = g_quark_from_static_string ("menu"))))) || (_tmp13_ == ((0 != _tmp12_label3) ? _tmp12_label3 : (_tmp12_label3 = g_quark_from_static_string ("session"))))) {
		switch (0) {
			default:
			{
				GtkBox* _tmp14_;
				_tmp14_ = self->priv->no_options_box;
				gtk_widget_show ((GtkWidget*) _tmp14_);
				gnome_pie_new_slice_window_set_icon (self, icon);
				break;
			}
		}
	} else if (_tmp13_ == ((0 != _tmp12_label4) ? _tmp12_label4 : (_tmp12_label4 = g_quark_from_static_string ("window_list")))) {
		switch (0) {
			default:
			{
				GtkBox* _tmp15_;
				_tmp15_ = self->priv->workspace_only_box;
				gtk_widget_show ((GtkWidget*) _tmp15_);
				gnome_pie_new_slice_window_set_icon (self, icon);
				break;
			}
		}
	} else if (_tmp13_ == ((0 != _tmp12_label5) ? _tmp12_label5 : (_tmp12_label5 = g_quark_from_static_string ("clipboard")))) {
		switch (0) {
			default:
			{
				GtkBox* _tmp16_;
				_tmp16_ = self->priv->clipboard_box;
				gtk_widget_show ((GtkWidget*) _tmp16_);
				gnome_pie_new_slice_window_set_icon (self, icon);
				break;
			}
		}
	} else if (_tmp13_ == ((0 != _tmp12_label6) ? _tmp12_label6 : (_tmp12_label6 = g_quark_from_static_string ("app")))) {
		switch (0) {
			default:
			{
				GtkBox* _tmp17_;
				GtkBox* _tmp18_;
				GtkBox* _tmp19_;
				GtkButton* _tmp20_;
				const gchar* _tmp21_;
				_tmp17_ = self->priv->name_box;
				gtk_widget_show ((GtkWidget*) _tmp17_);
				_tmp18_ = self->priv->command_box;
				gtk_widget_show ((GtkWidget*) _tmp18_);
				_tmp19_ = self->priv->quickaction_box;
				gtk_widget_show ((GtkWidget*) _tmp19_);
				_tmp20_ = self->priv->icon_button;
				gtk_widget_set_sensitive ((GtkWidget*) _tmp20_, TRUE);
				_tmp21_ = self->priv->current_custom_icon;
				if (g_strcmp0 (_tmp21_, "") == 0) {
					gnome_pie_new_slice_window_set_icon (self, icon);
				} else {
					const gchar* _tmp22_;
					_tmp22_ = self->priv->current_custom_icon;
					gnome_pie_new_slice_window_set_icon (self, _tmp22_);
				}
				break;
			}
		}
	} else if (_tmp13_ == ((0 != _tmp12_label7) ? _tmp12_label7 : (_tmp12_label7 = g_quark_from_static_string ("key")))) {
		switch (0) {
			default:
			{
				GtkBox* _tmp23_;
				GtkBox* _tmp24_;
				GtkBox* _tmp25_;
				GtkButton* _tmp26_;
				const gchar* _tmp27_;
				_tmp23_ = self->priv->name_box;
				gtk_widget_show ((GtkWidget*) _tmp23_);
				_tmp24_ = self->priv->hotkey_box;
				gtk_widget_show ((GtkWidget*) _tmp24_);
				_tmp25_ = self->priv->quickaction_box;
				gtk_widget_show ((GtkWidget*) _tmp25_);
				_tmp26_ = self->priv->icon_button;
				gtk_widget_set_sensitive ((GtkWidget*) _tmp26_, TRUE);
				_tmp27_ = self->priv->current_custom_icon;
				if (g_strcmp0 (_tmp27_, "") == 0) {
					gnome_pie_new_slice_window_set_icon (self, icon);
				} else {
					const gchar* _tmp28_;
					_tmp28_ = self->priv->current_custom_icon;
					gnome_pie_new_slice_window_set_icon (self, _tmp28_);
				}
				break;
			}
		}
	} else if (_tmp13_ == ((0 != _tmp12_label8) ? _tmp12_label8 : (_tmp12_label8 = g_quark_from_static_string ("pie")))) {
		switch (0) {
			default:
			{
				GtkBox* _tmp29_;
				GtkBox* _tmp30_;
				GeeHashMap* _tmp31_;
				GeeHashMap* _tmp32_;
				GnomePiePieComboList* _tmp33_;
				const gchar* _tmp34_;
				const gchar* _tmp35_;
				gpointer _tmp36_;
				GnomePiePie* _tmp37_;
				const gchar* _tmp38_;
				const gchar* _tmp39_;
				_tmp29_ = self->priv->pie_box;
				gtk_widget_show ((GtkWidget*) _tmp29_);
				_tmp30_ = self->priv->quickaction_box;
				gtk_widget_show ((GtkWidget*) _tmp30_);
				_tmp31_ = gnome_pie_pie_manager_get_all_pies ();
				_tmp32_ = _tmp31_;
				_tmp33_ = self->priv->pie_select;
				_tmp34_ = gnome_pie_pie_combo_list_get_current_id (_tmp33_);
				_tmp35_ = _tmp34_;
				_tmp36_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp32_, _tmp35_);
				_tmp37_ = (GnomePiePie*) _tmp36_;
				_tmp38_ = gnome_pie_pie_get_icon (_tmp37_);
				_tmp39_ = _tmp38_;
				gnome_pie_new_slice_window_set_icon (self, _tmp39_);
				_g_object_unref0 (_tmp37_);
				break;
			}
		}
	} else if (_tmp13_ == ((0 != _tmp12_label9) ? _tmp12_label9 : (_tmp12_label9 = g_quark_from_static_string ("uri")))) {
		switch (0) {
			default:
			{
				GtkBox* _tmp40_;
				GtkBox* _tmp41_;
				GtkBox* _tmp42_;
				GtkButton* _tmp43_;
				const gchar* _tmp44_;
				_tmp40_ = self->priv->name_box;
				gtk_widget_show ((GtkWidget*) _tmp40_);
				_tmp41_ = self->priv->uri_box;
				gtk_widget_show ((GtkWidget*) _tmp41_);
				_tmp42_ = self->priv->quickaction_box;
				gtk_widget_show ((GtkWidget*) _tmp42_);
				_tmp43_ = self->priv->icon_button;
				gtk_widget_set_sensitive ((GtkWidget*) _tmp43_, TRUE);
				_tmp44_ = self->priv->current_custom_icon;
				if (g_strcmp0 (_tmp44_, "") == 0) {
					gnome_pie_new_slice_window_set_icon (self, icon);
				} else {
					const gchar* _tmp45_;
					_tmp45_ = self->priv->current_custom_icon;
					gnome_pie_new_slice_window_set_icon (self, _tmp45_);
				}
				break;
			}
		}
	}
}

static void
____lambda55__gnome_pie_slice_type_list_on_select (GnomePieSliceTypeList* _sender,
                                                   const gchar* id,
                                                   const gchar* icon_name,
                                                   gpointer self)
{
	___lambda55_ ((GnomePieNewSliceWindow*) self, id, icon_name);
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

static void
___lambda56_ (GnomePieNewSliceWindow* self,
              const gchar* id)
{
	gchar* _tmp0_;
	GeeHashMap* _tmp1_;
	GeeHashMap* _tmp2_;
	gpointer _tmp3_;
	GnomePiePie* _tmp4_;
	const gchar* _tmp5_;
	const gchar* _tmp6_;
	g_return_if_fail (id != NULL);
	_tmp0_ = g_strdup (id);
	_g_free0 (self->priv->current_pie_to_open);
	self->priv->current_pie_to_open = _tmp0_;
	_tmp1_ = gnome_pie_pie_manager_get_all_pies ();
	_tmp2_ = _tmp1_;
	_tmp3_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp2_, id);
	_tmp4_ = (GnomePiePie*) _tmp3_;
	_tmp5_ = gnome_pie_pie_get_icon (_tmp4_);
	_tmp6_ = _tmp5_;
	gnome_pie_new_slice_window_set_icon (self, _tmp6_);
	_g_object_unref0 (_tmp4_);
}

static void
____lambda56__gnome_pie_pie_combo_list_on_select (GnomePiePieComboList* _sender,
                                                  const gchar* id,
                                                  gpointer self)
{
	___lambda56_ ((GnomePieNewSliceWindow*) self, id);
}

static void
___lambda57_ (GnomePieNewSliceWindow* self,
              GnomePieTrigger* trigger)
{
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	gchar* _tmp2_;
	g_return_if_fail (trigger != NULL);
	_tmp0_ = gnome_pie_trigger_get_name (trigger);
	_tmp1_ = _tmp0_;
	_tmp2_ = g_strdup (_tmp1_);
	_g_free0 (self->priv->current_hotkey);
	self->priv->current_hotkey = _tmp2_;
}

static void
____lambda57__gnome_pie_trigger_select_button_on_select (GnomePieTriggerSelectButton* _sender,
                                                         GnomePieTrigger* trigger,
                                                         gpointer self)
{
	___lambda57_ ((GnomePieNewSliceWindow*) self, trigger);
}

static void
___lambda58_ (GnomePieNewSliceWindow* self,
              const gchar* name,
              const gchar* command,
              const gchar* icon)
{
	GtkEntry* _tmp0_;
	g_return_if_fail (name != NULL);
	g_return_if_fail (command != NULL);
	g_return_if_fail (icon != NULL);
	gnome_pie_new_slice_window_set_icon (self, icon);
	_tmp0_ = self->priv->name_entry;
	gtk_entry_set_text (_tmp0_, name);
}

static void
____lambda58__gnome_pie_command_combo_list_on_select (GnomePieCommandComboList* _sender,
                                                      const gchar* name,
                                                      const gchar* command,
                                                      const gchar* icon,
                                                      gpointer self)
{
	___lambda58_ ((GnomePieNewSliceWindow*) self, name, command, icon);
}

static void
_gnome_pie_new_slice_window_on_icon_button_clicked_gtk_button_clicked (GtkButton* _sender,
                                                                       gpointer self)
{
	gnome_pie_new_slice_window_on_icon_button_clicked ((GnomePieNewSliceWindow*) self, _sender);
}

static void
_gnome_pie_new_slice_window_on_ok_button_clicked_gtk_button_clicked (GtkButton* _sender,
                                                                     gpointer self)
{
	gnome_pie_new_slice_window_on_ok_button_clicked ((GnomePieNewSliceWindow*) self);
}

static void
_gnome_pie_new_slice_window_on_cancel_button_clicked_gtk_button_clicked (GtkButton* _sender,
                                                                         gpointer self)
{
	gnome_pie_new_slice_window_on_cancel_button_clicked ((GnomePieNewSliceWindow*) self);
}

static gboolean
_gtk_widget_hide_on_delete_gtk_widget_delete_event (GtkWidget* _sender,
                                                    GdkEventAny* event,
                                                    gpointer self)
{
	gboolean result;
	result = gtk_widget_hide_on_delete ((GtkWidget*) self);
	return result;
}

GnomePieNewSliceWindow*
gnome_pie_new_slice_window_construct (GType object_type)
{
	GnomePieNewSliceWindow * self = NULL;
	GError* _inner_error0_ = NULL;
	self = (GnomePieNewSliceWindow*) g_object_new (object_type, NULL);
	{
		GtkBuilder* builder = NULL;
		GtkBuilder* _tmp0_;
		const gchar* _tmp1_;
		const gchar* _tmp2_;
		gchar* _tmp3_;
		gchar* _tmp4_;
		GnomePieSliceTypeList* _tmp5_;
		GnomePieSliceTypeList* _tmp6_;
		GObject* _tmp7_;
		GtkBox* _tmp8_;
		GObject* _tmp9_;
		GtkBox* _tmp10_;
		GObject* _tmp11_;
		GtkButton* _tmp12_;
		GObject* _tmp13_;
		GtkBox* _tmp14_;
		GObject* _tmp15_;
		GtkBox* _tmp16_;
		GnomePiePieComboList* _tmp17_;
		GnomePiePieComboList* _tmp18_;
		GtkBox* _tmp19_;
		GnomePiePieComboList* _tmp20_;
		GObject* _tmp21_;
		GtkBox* _tmp22_;
		GnomePieTriggerSelectButton* _tmp23_;
		GtkBox* _tmp24_;
		GnomePieTriggerSelectButton* _tmp25_;
		GnomePieTriggerSelectButton* _tmp26_;
		GObject* _tmp27_;
		GtkBox* _tmp28_;
		GObject* _tmp29_;
		GtkEntry* _tmp30_;
		GObject* _tmp31_;
		GtkEntry* _tmp32_;
		GObject* _tmp33_;
		GtkSwitch* _tmp34_;
		GObject* _tmp35_;
		GtkBox* _tmp36_;
		GObject* _tmp37_;
		GtkImage* _tmp38_;
		GnomePieCommandComboList* _tmp39_;
		GnomePieCommandComboList* _tmp40_;
		GtkBox* _tmp41_;
		GnomePieCommandComboList* _tmp42_;
		GObject* _tmp43_;
		GtkSwitch* _tmp44_;
		GObject* _tmp45_;
		GtkBox* _tmp46_;
		GObject* _tmp47_;
		GtkBox* _tmp48_;
		GObject* _tmp49_;
		GtkScale* _tmp50_;
		GtkScale* _tmp51_;
		GtkScale* _tmp52_;
		GtkButton* _tmp53_;
		GtkScrolledWindow* scroll_area = NULL;
		GObject* _tmp54_;
		GtkScrolledWindow* _tmp55_;
		GnomePieSliceTypeList* _tmp56_;
		GObject* _tmp57_;
		GtkDialog* _tmp58_;
		GObject* _tmp59_;
		GObject* _tmp60_;
		GtkDialog* _tmp61_;
		GtkDialog* _tmp62_;
		_tmp0_ = gtk_builder_new ();
		builder = _tmp0_;
		_tmp1_ = gnome_pie_paths_get_ui_files ();
		_tmp2_ = _tmp1_;
		_tmp3_ = g_strconcat (_tmp2_, "/slice_select.ui", NULL);
		_tmp4_ = _tmp3_;
		gtk_builder_add_from_file (builder, _tmp4_, &_inner_error0_);
		_g_free0 (_tmp4_);
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
			_g_object_unref0 (builder);
			goto __catch0_g_error;
		}
		_tmp5_ = gnome_pie_slice_type_list_new ();
		g_object_ref_sink (_tmp5_);
		_g_object_unref0 (self->priv->slice_type_list);
		self->priv->slice_type_list = _tmp5_;
		_tmp6_ = self->priv->slice_type_list;
		g_signal_connect_object (_tmp6_, "on-select", (GCallback) ____lambda55__gnome_pie_slice_type_list_on_select, self, 0);
		_tmp7_ = gtk_builder_get_object (builder, "name-box");
		_tmp8_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp7_, gtk_box_get_type ()) ? ((GtkBox*) _tmp7_) : NULL);
		_g_object_unref0 (self->priv->name_box);
		self->priv->name_box = _tmp8_;
		_tmp9_ = gtk_builder_get_object (builder, "command-box");
		_tmp10_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp9_, gtk_box_get_type ()) ? ((GtkBox*) _tmp9_) : NULL);
		_g_object_unref0 (self->priv->command_box);
		self->priv->command_box = _tmp10_;
		_tmp11_ = gtk_builder_get_object (builder, "icon-button");
		_tmp12_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp11_, gtk_button_get_type ()) ? ((GtkButton*) _tmp11_) : NULL);
		_g_object_unref0 (self->priv->icon_button);
		self->priv->icon_button = _tmp12_;
		_tmp13_ = gtk_builder_get_object (builder, "no-options-box");
		_tmp14_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp13_, gtk_box_get_type ()) ? ((GtkBox*) _tmp13_) : NULL);
		_g_object_unref0 (self->priv->no_options_box);
		self->priv->no_options_box = _tmp14_;
		_tmp15_ = gtk_builder_get_object (builder, "pie-box");
		_tmp16_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp15_, gtk_box_get_type ()) ? ((GtkBox*) _tmp15_) : NULL);
		_g_object_unref0 (self->priv->pie_box);
		self->priv->pie_box = _tmp16_;
		_tmp17_ = gnome_pie_pie_combo_list_new ();
		g_object_ref_sink (_tmp17_);
		_g_object_unref0 (self->priv->pie_select);
		self->priv->pie_select = _tmp17_;
		_tmp18_ = self->priv->pie_select;
		g_signal_connect_object (_tmp18_, "on-select", (GCallback) ____lambda56__gnome_pie_pie_combo_list_on_select, self, 0);
		_tmp19_ = self->priv->pie_box;
		_tmp20_ = self->priv->pie_select;
		gtk_box_pack_start (_tmp19_, (GtkWidget*) _tmp20_, TRUE, TRUE, (guint) 0);
		_tmp21_ = gtk_builder_get_object (builder, "hotkey-box");
		_tmp22_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp21_, gtk_box_get_type ()) ? ((GtkBox*) _tmp21_) : NULL);
		_g_object_unref0 (self->priv->hotkey_box);
		self->priv->hotkey_box = _tmp22_;
		_tmp23_ = gnome_pie_trigger_select_button_new (FALSE);
		g_object_ref_sink (_tmp23_);
		_g_object_unref0 (self->priv->key_select);
		self->priv->key_select = _tmp23_;
		_tmp24_ = self->priv->hotkey_box;
		_tmp25_ = self->priv->key_select;
		gtk_box_pack_start (_tmp24_, (GtkWidget*) _tmp25_, FALSE, TRUE, (guint) 0);
		_tmp26_ = self->priv->key_select;
		g_signal_connect_object (_tmp26_, "on-select", (GCallback) ____lambda57__gnome_pie_trigger_select_button_on_select, self, 0);
		_tmp27_ = gtk_builder_get_object (builder, "uri-box");
		_tmp28_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp27_, gtk_box_get_type ()) ? ((GtkBox*) _tmp27_) : NULL);
		_g_object_unref0 (self->priv->uri_box);
		self->priv->uri_box = _tmp28_;
		_tmp29_ = gtk_builder_get_object (builder, "name-entry");
		_tmp30_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp29_, gtk_entry_get_type ()) ? ((GtkEntry*) _tmp29_) : NULL);
		_g_object_unref0 (self->priv->name_entry);
		self->priv->name_entry = _tmp30_;
		_tmp31_ = gtk_builder_get_object (builder, "uri-entry");
		_tmp32_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp31_, gtk_entry_get_type ()) ? ((GtkEntry*) _tmp31_) : NULL);
		_g_object_unref0 (self->priv->uri_entry);
		self->priv->uri_entry = _tmp32_;
		_tmp33_ = gtk_builder_get_object (builder, "quick-action-checkbutton");
		_tmp34_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp33_, gtk_switch_get_type ()) ? ((GtkSwitch*) _tmp33_) : NULL);
		_g_object_unref0 (self->priv->quickaction_checkbutton);
		self->priv->quickaction_checkbutton = _tmp34_;
		_tmp35_ = gtk_builder_get_object (builder, "quickaction-box");
		_tmp36_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp35_, gtk_box_get_type ()) ? ((GtkBox*) _tmp35_) : NULL);
		_g_object_unref0 (self->priv->quickaction_box);
		self->priv->quickaction_box = _tmp36_;
		_tmp37_ = gtk_builder_get_object (builder, "icon");
		_tmp38_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp37_, gtk_image_get_type ()) ? ((GtkImage*) _tmp37_) : NULL);
		_g_object_unref0 (self->priv->icon);
		self->priv->icon = _tmp38_;
		_tmp39_ = gnome_pie_command_combo_list_new ();
		g_object_ref_sink (_tmp39_);
		_g_object_unref0 (self->priv->command_list);
		self->priv->command_list = _tmp39_;
		_tmp40_ = self->priv->command_list;
		g_signal_connect_object (_tmp40_, "on-select", (GCallback) ____lambda58__gnome_pie_command_combo_list_on_select, self, 0);
		_tmp41_ = self->priv->command_box;
		_tmp42_ = self->priv->command_list;
		gtk_box_pack_start (_tmp41_, (GtkWidget*) _tmp42_, TRUE, TRUE, (guint) 0);
		_tmp43_ = gtk_builder_get_object (builder, "workspace-only-checkbutton");
		_tmp44_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp43_, gtk_switch_get_type ()) ? ((GtkSwitch*) _tmp43_) : NULL);
		_g_object_unref0 (self->priv->workspace_only_checkbutton);
		self->priv->workspace_only_checkbutton = _tmp44_;
		_tmp45_ = gtk_builder_get_object (builder, "workspace-only-box");
		_tmp46_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp45_, gtk_box_get_type ()) ? ((GtkBox*) _tmp45_) : NULL);
		_g_object_unref0 (self->priv->workspace_only_box);
		self->priv->workspace_only_box = _tmp46_;
		_tmp47_ = gtk_builder_get_object (builder, "clipboard-box");
		_tmp48_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp47_, gtk_box_get_type ()) ? ((GtkBox*) _tmp47_) : NULL);
		_g_object_unref0 (self->priv->clipboard_box);
		self->priv->clipboard_box = _tmp48_;
		_tmp49_ = gtk_builder_get_object (builder, "clipboard-scale");
		_tmp50_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp49_, gtk_scale_get_type ()) ? ((GtkScale*) _tmp49_) : NULL);
		_g_object_unref0 (self->priv->clipboard_slider);
		self->priv->clipboard_slider = _tmp50_;
		_tmp51_ = self->priv->clipboard_slider;
		gtk_range_set_range ((GtkRange*) _tmp51_, (gdouble) 2, (gdouble) 24);
		_tmp52_ = self->priv->clipboard_slider;
		gtk_range_set_value ((GtkRange*) _tmp52_, (gdouble) 8);
		_tmp53_ = self->priv->icon_button;
		g_signal_connect_object (_tmp53_, "clicked", (GCallback) _gnome_pie_new_slice_window_on_icon_button_clicked_gtk_button_clicked, self, 0);
		_tmp54_ = gtk_builder_get_object (builder, "slice-scrolledwindow");
		_tmp55_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp54_, gtk_scrolled_window_get_type ()) ? ((GtkScrolledWindow*) _tmp54_) : NULL);
		scroll_area = _tmp55_;
		_tmp56_ = self->priv->slice_type_list;
		gtk_container_add ((GtkContainer*) scroll_area, (GtkWidget*) _tmp56_);
		_tmp57_ = gtk_builder_get_object (builder, "window");
		_tmp58_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp57_, gtk_dialog_get_type ()) ? ((GtkDialog*) _tmp57_) : NULL);
		_g_object_unref0 (self->priv->window);
		self->priv->window = _tmp58_;
		_tmp59_ = gtk_builder_get_object (builder, "ok-button");
		g_signal_connect_object (G_TYPE_CHECK_INSTANCE_TYPE (_tmp59_, gtk_button_get_type ()) ? ((GtkButton*) _tmp59_) : NULL, "clicked", (GCallback) _gnome_pie_new_slice_window_on_ok_button_clicked_gtk_button_clicked, self, 0);
		_tmp60_ = gtk_builder_get_object (builder, "cancel-button");
		g_signal_connect_object (G_TYPE_CHECK_INSTANCE_TYPE (_tmp60_, gtk_button_get_type ()) ? ((GtkButton*) _tmp60_) : NULL, "clicked", (GCallback) _gnome_pie_new_slice_window_on_cancel_button_clicked_gtk_button_clicked, self, 0);
		_tmp61_ = self->priv->window;
		_tmp62_ = self->priv->window;
		g_signal_connect_object ((GtkWidget*) _tmp61_, "delete-event", (GCallback) _gtk_widget_hide_on_delete_gtk_widget_delete_event, (GtkWidget*) _tmp62_, 0);
		_g_object_unref0 (scroll_area);
		_g_object_unref0 (builder);
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp63_;
		e = _inner_error0_;
		_inner_error0_ = NULL;
		_tmp63_ = e->message;
		g_error ("newSliceWindow.vala:237: Could not load UI: %s\n", _tmp63_);
		_g_error_free0 (e);
	}
	__finally0:
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
		g_clear_error (&_inner_error0_);
		return NULL;
	}
	return self;
}

GnomePieNewSliceWindow*
gnome_pie_new_slice_window_new (void)
{
	return gnome_pie_new_slice_window_construct (GNOME_PIE_TYPE_NEW_SLICE_WINDOW);
}

void
gnome_pie_new_slice_window_set_parent (GnomePieNewSliceWindow* self,
                                       GtkWindow* parent)
{
	GtkDialog* _tmp0_;
	g_return_if_fail (self != NULL);
	g_return_if_fail (parent != NULL);
	_tmp0_ = self->priv->window;
	gtk_window_set_transient_for ((GtkWindow*) _tmp0_, parent);
}

void
gnome_pie_new_slice_window_show (GnomePieNewSliceWindow* self)
{
	GnomePieSliceTypeList* _tmp0_;
	GnomePiePieComboList* _tmp1_;
	GnomePieTriggerSelectButton* _tmp2_;
	GnomePieTrigger* _tmp3_;
	GnomePieTrigger* _tmp4_;
	GtkDialog* _tmp5_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->slice_type_list;
	gnome_pie_slice_type_list_select_first (_tmp0_);
	_tmp1_ = self->priv->pie_select;
	gnome_pie_pie_combo_list_select_first (_tmp1_);
	_tmp2_ = self->priv->key_select;
	_tmp3_ = gnome_pie_trigger_new ();
	_tmp4_ = _tmp3_;
	gnome_pie_trigger_select_button_set_trigger (_tmp2_, _tmp4_);
	_g_object_unref0 (_tmp4_);
	_tmp5_ = self->priv->window;
	gtk_widget_show_all ((GtkWidget*) _tmp5_);
}

void
gnome_pie_new_slice_window_reload (GnomePieNewSliceWindow* self)
{
	GnomePiePieComboList* _tmp0_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->pie_select;
	gnome_pie_pie_combo_list_reload (_tmp0_);
}

void
gnome_pie_new_slice_window_set_action (GnomePieNewSliceWindow* self,
                                       GnomePieActionGroup* group,
                                       gint position)
{
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	gchar* type = NULL;
	gchar* _tmp2_;
	g_return_if_fail (self != NULL);
	g_return_if_fail (group != NULL);
	_tmp0_ = gnome_pie_action_group_get_parent_id (group);
	_tmp1_ = _tmp0_;
	gnome_pie_new_slice_window_set_default (self, _tmp1_, position);
	self->priv->add_as_new_slice = FALSE;
	_tmp2_ = g_strdup ("");
	type = _tmp2_;
	if (g_type_depth (G_TYPE_FROM_INSTANCE ((GObject*) group)) == ((guint) 2)) {
		GnomePieAction* action = NULL;
		GeeArrayList* _tmp3_;
		GeeArrayList* _tmp4_;
		gpointer _tmp5_;
		GeeHashMap* _tmp6_;
		GeeHashMap* _tmp7_;
		GnomePieAction* _tmp8_;
		const gchar* _tmp9_;
		gpointer _tmp10_;
		GnomePieActionRegistryTypeDescription* _tmp11_;
		const gchar* _tmp12_;
		const gchar* _tmp13_;
		gchar* _tmp14_;
		const gchar* _tmp15_;
		GnomePieAction* _tmp16_;
		const gchar* _tmp17_;
		const gchar* _tmp18_;
		GtkSwitch* _tmp19_;
		GnomePieAction* _tmp20_;
		gboolean _tmp21_;
		gboolean _tmp22_;
		GtkEntry* _tmp23_;
		GnomePieAction* _tmp24_;
		const gchar* _tmp25_;
		const gchar* _tmp26_;
		const gchar* _tmp27_;
		const gchar* _tmp28_;
		GQuark _tmp30_ = 0U;
		static GQuark _tmp29_label0 = 0;
		static GQuark _tmp29_label1 = 0;
		static GQuark _tmp29_label2 = 0;
		static GQuark _tmp29_label3 = 0;
		_tmp3_ = gnome_pie_action_group_get_actions (group);
		_tmp4_ = _tmp3_;
		_tmp5_ = gee_abstract_list_get ((GeeAbstractList*) _tmp4_, 0);
		action = (GnomePieAction*) _tmp5_;
		_tmp6_ = gnome_pie_action_registry_get_descriptions ();
		_tmp7_ = _tmp6_;
		_tmp8_ = action;
		_tmp9_ = g_type_name (G_TYPE_FROM_INSTANCE ((GObject*) _tmp8_));
		_tmp10_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp7_, _tmp9_);
		_tmp11_ = (GnomePieActionRegistryTypeDescription*) _tmp10_;
		_tmp12_ = gnome_pie_action_registry_typedescription_get_id (_tmp11_);
		_tmp13_ = _tmp12_;
		_tmp14_ = g_strdup (_tmp13_);
		_g_free0 (type);
		type = _tmp14_;
		_gnome_pie_action_registry_typedescription_unref0 (_tmp11_);
		_tmp15_ = type;
		gnome_pie_new_slice_window_select_type (self, _tmp15_);
		_tmp16_ = action;
		_tmp17_ = gnome_pie_action_get_icon (_tmp16_);
		_tmp18_ = _tmp17_;
		gnome_pie_new_slice_window_set_icon (self, _tmp18_);
		_tmp19_ = self->priv->quickaction_checkbutton;
		_tmp20_ = action;
		_tmp21_ = gnome_pie_action_get_is_quickaction (_tmp20_);
		_tmp22_ = _tmp21_;
		gtk_switch_set_active (_tmp19_, _tmp22_);
		_tmp23_ = self->priv->name_entry;
		_tmp24_ = action;
		_tmp25_ = gnome_pie_action_get_name (_tmp24_);
		_tmp26_ = _tmp25_;
		gtk_entry_set_text (_tmp23_, _tmp26_);
		_tmp27_ = type;
		_tmp28_ = _tmp27_;
		_tmp30_ = (NULL == _tmp28_) ? 0 : g_quark_from_string (_tmp28_);
		if (_tmp30_ == ((0 != _tmp29_label0) ? _tmp29_label0 : (_tmp29_label0 = g_quark_from_static_string ("app")))) {
			switch (0) {
				default:
				{
					GnomePieAction* _tmp31_;
					const gchar* _tmp32_;
					const gchar* _tmp33_;
					gchar* _tmp34_;
					GnomePieCommandComboList* _tmp35_;
					GnomePieAction* _tmp36_;
					const gchar* _tmp37_;
					const gchar* _tmp38_;
					_tmp31_ = action;
					_tmp32_ = gnome_pie_action_get_icon (_tmp31_);
					_tmp33_ = _tmp32_;
					_tmp34_ = g_strdup (_tmp33_);
					_g_free0 (self->priv->current_custom_icon);
					self->priv->current_custom_icon = _tmp34_;
					_tmp35_ = self->priv->command_list;
					_tmp36_ = action;
					_tmp37_ = gnome_pie_action_get_real_command (_tmp36_);
					_tmp38_ = _tmp37_;
					gnome_pie_command_combo_list_set_text (_tmp35_, _tmp38_);
					break;
				}
			}
		} else if (_tmp30_ == ((0 != _tmp29_label1) ? _tmp29_label1 : (_tmp29_label1 = g_quark_from_static_string ("key")))) {
			switch (0) {
				default:
				{
					GnomePieAction* _tmp39_;
					const gchar* _tmp40_;
					const gchar* _tmp41_;
					gchar* _tmp42_;
					GnomePieAction* _tmp43_;
					const gchar* _tmp44_;
					const gchar* _tmp45_;
					gchar* _tmp46_;
					GnomePieTriggerSelectButton* _tmp47_;
					GnomePieAction* _tmp48_;
					const gchar* _tmp49_;
					const gchar* _tmp50_;
					GnomePieTrigger* _tmp51_;
					GnomePieTrigger* _tmp52_;
					_tmp39_ = action;
					_tmp40_ = gnome_pie_action_get_icon (_tmp39_);
					_tmp41_ = _tmp40_;
					_tmp42_ = g_strdup (_tmp41_);
					_g_free0 (self->priv->current_custom_icon);
					self->priv->current_custom_icon = _tmp42_;
					_tmp43_ = action;
					_tmp44_ = gnome_pie_action_get_real_command (_tmp43_);
					_tmp45_ = _tmp44_;
					_tmp46_ = g_strdup (_tmp45_);
					_g_free0 (self->priv->current_hotkey);
					self->priv->current_hotkey = _tmp46_;
					_tmp47_ = self->priv->key_select;
					_tmp48_ = action;
					_tmp49_ = gnome_pie_action_get_real_command (_tmp48_);
					_tmp50_ = _tmp49_;
					_tmp51_ = gnome_pie_trigger_new_from_string (_tmp50_);
					_tmp52_ = _tmp51_;
					gnome_pie_trigger_select_button_set_trigger (_tmp47_, _tmp52_);
					_g_object_unref0 (_tmp52_);
					break;
				}
			}
		} else if (_tmp30_ == ((0 != _tmp29_label2) ? _tmp29_label2 : (_tmp29_label2 = g_quark_from_static_string ("pie")))) {
			switch (0) {
				default:
				{
					GnomePiePieComboList* _tmp53_;
					GnomePieAction* _tmp54_;
					const gchar* _tmp55_;
					const gchar* _tmp56_;
					_tmp53_ = self->priv->pie_select;
					_tmp54_ = action;
					_tmp55_ = gnome_pie_action_get_real_command (_tmp54_);
					_tmp56_ = _tmp55_;
					gnome_pie_pie_combo_list_select (_tmp53_, _tmp56_);
					break;
				}
			}
		} else if (_tmp30_ == ((0 != _tmp29_label3) ? _tmp29_label3 : (_tmp29_label3 = g_quark_from_static_string ("uri")))) {
			switch (0) {
				default:
				{
					GnomePieAction* _tmp57_;
					const gchar* _tmp58_;
					const gchar* _tmp59_;
					gchar* _tmp60_;
					GtkEntry* _tmp61_;
					GnomePieAction* _tmp62_;
					const gchar* _tmp63_;
					const gchar* _tmp64_;
					_tmp57_ = action;
					_tmp58_ = gnome_pie_action_get_icon (_tmp57_);
					_tmp59_ = _tmp58_;
					_tmp60_ = g_strdup (_tmp59_);
					_g_free0 (self->priv->current_custom_icon);
					self->priv->current_custom_icon = _tmp60_;
					_tmp61_ = self->priv->uri_entry;
					_tmp62_ = action;
					_tmp63_ = gnome_pie_action_get_real_command (_tmp62_);
					_tmp64_ = _tmp63_;
					gtk_entry_set_text (_tmp61_, _tmp64_);
					break;
				}
			}
		}
		_g_object_unref0 (action);
	} else {
		GeeHashMap* _tmp65_;
		GeeHashMap* _tmp66_;
		const gchar* _tmp67_;
		gpointer _tmp68_;
		GnomePieGroupRegistryTypeDescription* _tmp69_;
		const gchar* _tmp70_;
		const gchar* _tmp71_;
		gchar* _tmp72_;
		const gchar* _tmp73_;
		const gchar* _tmp74_;
		GQuark _tmp76_ = 0U;
		static GQuark _tmp75_label0 = 0;
		static GQuark _tmp75_label1 = 0;
		const gchar* _tmp83_;
		_tmp65_ = gnome_pie_group_registry_get_descriptions ();
		_tmp66_ = _tmp65_;
		_tmp67_ = g_type_name (G_TYPE_FROM_INSTANCE ((GObject*) group));
		_tmp68_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp66_, _tmp67_);
		_tmp69_ = (GnomePieGroupRegistryTypeDescription*) _tmp68_;
		_tmp70_ = gnome_pie_group_registry_typedescription_get_id (_tmp69_);
		_tmp71_ = _tmp70_;
		_tmp72_ = g_strdup (_tmp71_);
		_g_free0 (type);
		type = _tmp72_;
		_gnome_pie_group_registry_typedescription_unref0 (_tmp69_);
		_tmp73_ = type;
		_tmp74_ = _tmp73_;
		_tmp76_ = (NULL == _tmp74_) ? 0 : g_quark_from_string (_tmp74_);
		if (_tmp76_ == ((0 != _tmp75_label0) ? _tmp75_label0 : (_tmp75_label0 = g_quark_from_static_string ("clipboard")))) {
			switch (0) {
				default:
				{
					GtkScale* _tmp77_;
					gint _tmp78_;
					gint _tmp79_;
					_tmp77_ = self->priv->clipboard_slider;
					_tmp78_ = gnome_pie_clipboard_group_get_max_items (GNOME_PIE_IS_CLIPBOARD_GROUP (group) ? ((GnomePieClipboardGroup*) group) : NULL);
					_tmp79_ = _tmp78_;
					gtk_range_set_value ((GtkRange*) _tmp77_, (gdouble) _tmp79_);
					break;
				}
			}
		} else if (_tmp76_ == ((0 != _tmp75_label1) ? _tmp75_label1 : (_tmp75_label1 = g_quark_from_static_string ("window_list")))) {
			switch (0) {
				default:
				{
					GtkSwitch* _tmp80_;
					gboolean _tmp81_;
					gboolean _tmp82_;
					_tmp80_ = self->priv->workspace_only_checkbutton;
					_tmp81_ = gnome_pie_window_list_group_get_current_workspace_only (GNOME_PIE_IS_WINDOW_LIST_GROUP (group) ? ((GnomePieWindowListGroup*) group) : NULL);
					_tmp82_ = _tmp81_;
					gtk_switch_set_active (_tmp80_, _tmp82_);
					break;
				}
			}
		}
		_tmp83_ = type;
		gnome_pie_new_slice_window_select_type (self, _tmp83_);
	}
	_g_free0 (type);
}

void
gnome_pie_new_slice_window_set_default (GnomePieNewSliceWindow* self,
                                        const gchar* pie_id,
                                        gint position)
{
	gchar* _tmp0_;
	gchar* _tmp1_;
	GnomePieTriggerSelectButton* _tmp2_;
	GnomePieTrigger* _tmp3_;
	GnomePieTrigger* _tmp4_;
	GnomePiePieComboList* _tmp5_;
	GtkEntry* _tmp6_;
	GnomePieCommandComboList* _tmp7_;
	GtkEntry* _tmp8_;
	g_return_if_fail (self != NULL);
	g_return_if_fail (pie_id != NULL);
	self->priv->slice_position = position;
	self->priv->add_as_new_slice = TRUE;
	_tmp0_ = g_strdup ("");
	_g_free0 (self->priv->current_custom_icon);
	self->priv->current_custom_icon = _tmp0_;
	gnome_pie_new_slice_window_select_type (self, "app");
	_tmp1_ = g_strdup (pie_id);
	_g_free0 (self->priv->current_id);
	self->priv->current_id = _tmp1_;
	_tmp2_ = self->priv->key_select;
	_tmp3_ = gnome_pie_trigger_new ();
	_tmp4_ = _tmp3_;
	gnome_pie_trigger_select_button_set_trigger (_tmp2_, _tmp4_);
	_g_object_unref0 (_tmp4_);
	_tmp5_ = self->priv->pie_select;
	gnome_pie_pie_combo_list_select_first (_tmp5_);
	_tmp6_ = self->priv->name_entry;
	gtk_entry_set_text (_tmp6_, _ ("Rename me!"));
	_tmp7_ = self->priv->command_list;
	gnome_pie_command_combo_list_set_text (_tmp7_, "");
	_tmp8_ = self->priv->uri_entry;
	gtk_entry_set_text (_tmp8_, "");
}

static void
gnome_pie_new_slice_window_select_type (GnomePieNewSliceWindow* self,
                                        const gchar* type)
{
	gchar* _tmp0_;
	GnomePieSliceTypeList* _tmp1_;
	g_return_if_fail (self != NULL);
	g_return_if_fail (type != NULL);
	_tmp0_ = g_strdup (type);
	_g_free0 (self->priv->current_type);
	self->priv->current_type = _tmp0_;
	_tmp1_ = self->priv->slice_type_list;
	gnome_pie_slice_type_list_select (_tmp1_, type);
}

static void
gnome_pie_new_slice_window_on_ok_button_clicked (GnomePieNewSliceWindow* self)
{
	GtkDialog* _tmp0_;
	GnomePieActionGroup* group = NULL;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	GQuark _tmp4_ = 0U;
	static GQuark _tmp3_label0 = 0;
	static GQuark _tmp3_label1 = 0;
	static GQuark _tmp3_label2 = 0;
	static GQuark _tmp3_label3 = 0;
	static GQuark _tmp3_label4 = 0;
	static GQuark _tmp3_label5 = 0;
	static GQuark _tmp3_label6 = 0;
	static GQuark _tmp3_label7 = 0;
	static GQuark _tmp3_label8 = 0;
	static GQuark _tmp3_label9 = 0;
	GnomePieActionGroup* _tmp79_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->window;
	gtk_widget_hide ((GtkWidget*) _tmp0_);
	group = NULL;
	_tmp1_ = self->priv->current_type;
	_tmp2_ = _tmp1_;
	_tmp4_ = (NULL == _tmp2_) ? 0 : g_quark_from_string (_tmp2_);
	if (_tmp4_ == ((0 != _tmp3_label0) ? _tmp3_label0 : (_tmp3_label0 = g_quark_from_static_string ("bookmarks")))) {
		switch (0) {
			default:
			{
				const gchar* _tmp5_;
				GnomePieBookmarkGroup* _tmp6_;
				_tmp5_ = self->priv->current_id;
				_tmp6_ = gnome_pie_bookmark_group_new (_tmp5_);
				_g_object_unref0 (group);
				group = (GnomePieActionGroup*) _tmp6_;
				break;
			}
		}
	} else if (_tmp4_ == ((0 != _tmp3_label1) ? _tmp3_label1 : (_tmp3_label1 = g_quark_from_static_string ("devices")))) {
		switch (0) {
			default:
			{
				const gchar* _tmp7_;
				GnomePieDevicesGroup* _tmp8_;
				_tmp7_ = self->priv->current_id;
				_tmp8_ = gnome_pie_devices_group_new (_tmp7_);
				_g_object_unref0 (group);
				group = (GnomePieActionGroup*) _tmp8_;
				break;
			}
		}
	} else if (_tmp4_ == ((0 != _tmp3_label2) ? _tmp3_label2 : (_tmp3_label2 = g_quark_from_static_string ("menu")))) {
		switch (0) {
			default:
			{
				const gchar* _tmp9_;
				GnomePieMenuGroup* _tmp10_;
				_tmp9_ = self->priv->current_id;
				_tmp10_ = gnome_pie_menu_group_new (_tmp9_);
				_g_object_unref0 (group);
				group = (GnomePieActionGroup*) _tmp10_;
				break;
			}
		}
	} else if (_tmp4_ == ((0 != _tmp3_label3) ? _tmp3_label3 : (_tmp3_label3 = g_quark_from_static_string ("session")))) {
		switch (0) {
			default:
			{
				const gchar* _tmp11_;
				GnomePieSessionGroup* _tmp12_;
				_tmp11_ = self->priv->current_id;
				_tmp12_ = gnome_pie_session_group_new (_tmp11_);
				_g_object_unref0 (group);
				group = (GnomePieActionGroup*) _tmp12_;
				break;
			}
		}
	} else if (_tmp4_ == ((0 != _tmp3_label4) ? _tmp3_label4 : (_tmp3_label4 = g_quark_from_static_string ("clipboard")))) {
		switch (0) {
			default:
			{
				GnomePieClipboardGroup* g = NULL;
				const gchar* _tmp13_;
				GnomePieClipboardGroup* _tmp14_;
				GnomePieClipboardGroup* _tmp15_;
				GtkScale* _tmp16_;
				GnomePieClipboardGroup* _tmp17_;
				GnomePieActionGroup* _tmp18_;
				_tmp13_ = self->priv->current_id;
				_tmp14_ = gnome_pie_clipboard_group_new (_tmp13_);
				g = _tmp14_;
				_tmp15_ = g;
				_tmp16_ = self->priv->clipboard_slider;
				gnome_pie_clipboard_group_set_max_items (_tmp15_, (gint) gtk_range_get_value ((GtkRange*) _tmp16_));
				_tmp17_ = g;
				_tmp18_ = _g_object_ref0 ((GnomePieActionGroup*) _tmp17_);
				_g_object_unref0 (group);
				group = _tmp18_;
				_g_object_unref0 (g);
				break;
			}
		}
	} else if (_tmp4_ == ((0 != _tmp3_label5) ? _tmp3_label5 : (_tmp3_label5 = g_quark_from_static_string ("window_list")))) {
		switch (0) {
			default:
			{
				GnomePieWindowListGroup* g = NULL;
				const gchar* _tmp19_;
				GnomePieWindowListGroup* _tmp20_;
				GnomePieWindowListGroup* _tmp21_;
				GtkSwitch* _tmp22_;
				gboolean _tmp23_;
				gboolean _tmp24_;
				GnomePieWindowListGroup* _tmp25_;
				GnomePieActionGroup* _tmp26_;
				_tmp19_ = self->priv->current_id;
				_tmp20_ = gnome_pie_window_list_group_new (_tmp19_);
				g = _tmp20_;
				_tmp21_ = g;
				_tmp22_ = self->priv->workspace_only_checkbutton;
				_tmp23_ = gtk_switch_get_active (_tmp22_);
				_tmp24_ = _tmp23_;
				gnome_pie_window_list_group_set_current_workspace_only (_tmp21_, _tmp24_);
				_tmp25_ = g;
				_tmp26_ = _g_object_ref0 ((GnomePieActionGroup*) _tmp25_);
				_g_object_unref0 (group);
				group = _tmp26_;
				_g_object_unref0 (g);
				break;
			}
		}
	} else if (_tmp4_ == ((0 != _tmp3_label6) ? _tmp3_label6 : (_tmp3_label6 = g_quark_from_static_string ("app")))) {
		switch (0) {
			default:
			{
				const gchar* _tmp27_;
				GnomePieActionGroup* _tmp28_;
				GnomePieActionGroup* _tmp29_;
				GtkEntry* _tmp30_;
				const gchar* _tmp31_;
				const gchar* _tmp32_;
				const gchar* _tmp33_;
				GnomePieCommandComboList* _tmp34_;
				const gchar* _tmp35_;
				const gchar* _tmp36_;
				GtkSwitch* _tmp37_;
				gboolean _tmp38_;
				gboolean _tmp39_;
				GnomePieAppAction* _tmp40_;
				GnomePieAppAction* _tmp41_;
				_tmp27_ = self->priv->current_id;
				_tmp28_ = gnome_pie_action_group_new (_tmp27_);
				_g_object_unref0 (group);
				group = _tmp28_;
				_tmp29_ = group;
				_tmp30_ = self->priv->name_entry;
				_tmp31_ = gtk_entry_get_text (_tmp30_);
				_tmp32_ = _tmp31_;
				_tmp33_ = self->priv->current_icon;
				_tmp34_ = self->priv->command_list;
				_tmp35_ = gnome_pie_command_combo_list_get_text (_tmp34_);
				_tmp36_ = _tmp35_;
				_tmp37_ = self->priv->quickaction_checkbutton;
				_tmp38_ = gtk_switch_get_active (_tmp37_);
				_tmp39_ = _tmp38_;
				_tmp40_ = gnome_pie_app_action_new (_tmp32_, _tmp33_, _tmp36_, _tmp39_);
				_tmp41_ = _tmp40_;
				gnome_pie_action_group_add_action (_tmp29_, (GnomePieAction*) _tmp41_);
				_g_object_unref0 (_tmp41_);
				break;
			}
		}
	} else if (_tmp4_ == ((0 != _tmp3_label7) ? _tmp3_label7 : (_tmp3_label7 = g_quark_from_static_string ("key")))) {
		switch (0) {
			default:
			{
				const gchar* _tmp42_;
				GnomePieActionGroup* _tmp43_;
				GnomePieActionGroup* _tmp44_;
				GtkEntry* _tmp45_;
				const gchar* _tmp46_;
				const gchar* _tmp47_;
				const gchar* _tmp48_;
				const gchar* _tmp49_;
				GtkSwitch* _tmp50_;
				gboolean _tmp51_;
				gboolean _tmp52_;
				GnomePieKeyAction* _tmp53_;
				GnomePieKeyAction* _tmp54_;
				_tmp42_ = self->priv->current_id;
				_tmp43_ = gnome_pie_action_group_new (_tmp42_);
				_g_object_unref0 (group);
				group = _tmp43_;
				_tmp44_ = group;
				_tmp45_ = self->priv->name_entry;
				_tmp46_ = gtk_entry_get_text (_tmp45_);
				_tmp47_ = _tmp46_;
				_tmp48_ = self->priv->current_icon;
				_tmp49_ = self->priv->current_hotkey;
				_tmp50_ = self->priv->quickaction_checkbutton;
				_tmp51_ = gtk_switch_get_active (_tmp50_);
				_tmp52_ = _tmp51_;
				_tmp53_ = gnome_pie_key_action_new (_tmp47_, _tmp48_, _tmp49_, _tmp52_);
				_tmp54_ = _tmp53_;
				gnome_pie_action_group_add_action (_tmp44_, (GnomePieAction*) _tmp54_);
				_g_object_unref0 (_tmp54_);
				break;
			}
		}
	} else if (_tmp4_ == ((0 != _tmp3_label8) ? _tmp3_label8 : (_tmp3_label8 = g_quark_from_static_string ("pie")))) {
		switch (0) {
			default:
			{
				const gchar* _tmp55_;
				GnomePieActionGroup* _tmp56_;
				GnomePieActionGroup* _tmp57_;
				const gchar* _tmp58_;
				GtkSwitch* _tmp59_;
				gboolean _tmp60_;
				gboolean _tmp61_;
				GnomePiePieAction* _tmp62_;
				GnomePiePieAction* _tmp63_;
				_tmp55_ = self->priv->current_id;
				_tmp56_ = gnome_pie_action_group_new (_tmp55_);
				_g_object_unref0 (group);
				group = _tmp56_;
				_tmp57_ = group;
				_tmp58_ = self->priv->current_pie_to_open;
				_tmp59_ = self->priv->quickaction_checkbutton;
				_tmp60_ = gtk_switch_get_active (_tmp59_);
				_tmp61_ = _tmp60_;
				_tmp62_ = gnome_pie_pie_action_new (_tmp58_, _tmp61_);
				_tmp63_ = _tmp62_;
				gnome_pie_action_group_add_action (_tmp57_, (GnomePieAction*) _tmp63_);
				_g_object_unref0 (_tmp63_);
				break;
			}
		}
	} else if (_tmp4_ == ((0 != _tmp3_label9) ? _tmp3_label9 : (_tmp3_label9 = g_quark_from_static_string ("uri")))) {
		switch (0) {
			default:
			{
				const gchar* _tmp64_;
				GnomePieActionGroup* _tmp65_;
				GnomePieActionGroup* _tmp66_;
				GtkEntry* _tmp67_;
				const gchar* _tmp68_;
				const gchar* _tmp69_;
				const gchar* _tmp70_;
				GtkEntry* _tmp71_;
				const gchar* _tmp72_;
				const gchar* _tmp73_;
				GtkSwitch* _tmp74_;
				gboolean _tmp75_;
				gboolean _tmp76_;
				GnomePieUriAction* _tmp77_;
				GnomePieUriAction* _tmp78_;
				_tmp64_ = self->priv->current_id;
				_tmp65_ = gnome_pie_action_group_new (_tmp64_);
				_g_object_unref0 (group);
				group = _tmp65_;
				_tmp66_ = group;
				_tmp67_ = self->priv->name_entry;
				_tmp68_ = gtk_entry_get_text (_tmp67_);
				_tmp69_ = _tmp68_;
				_tmp70_ = self->priv->current_icon;
				_tmp71_ = self->priv->uri_entry;
				_tmp72_ = gtk_entry_get_text (_tmp71_);
				_tmp73_ = _tmp72_;
				_tmp74_ = self->priv->quickaction_checkbutton;
				_tmp75_ = gtk_switch_get_active (_tmp74_);
				_tmp76_ = _tmp75_;
				_tmp77_ = gnome_pie_uri_action_new (_tmp69_, _tmp70_, _tmp73_, _tmp76_);
				_tmp78_ = _tmp77_;
				gnome_pie_action_group_add_action (_tmp66_, (GnomePieAction*) _tmp78_);
				_g_object_unref0 (_tmp78_);
				break;
			}
		}
	}
	_tmp79_ = group;
	g_signal_emit (self, gnome_pie_new_slice_window_signals[GNOME_PIE_NEW_SLICE_WINDOW_ON_SELECT_SIGNAL], 0, _tmp79_, self->priv->add_as_new_slice, self->priv->slice_position);
	_g_object_unref0 (group);
}

static void
gnome_pie_new_slice_window_on_cancel_button_clicked (GnomePieNewSliceWindow* self)
{
	GtkDialog* _tmp0_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->window;
	gtk_widget_hide ((GtkWidget*) _tmp0_);
}

static void
___lambda59_ (GnomePieNewSliceWindow* self,
              const gchar* icon)
{
	gchar* _tmp0_;
	g_return_if_fail (icon != NULL);
	_tmp0_ = g_strdup (icon);
	_g_free0 (self->priv->current_custom_icon);
	self->priv->current_custom_icon = _tmp0_;
	gnome_pie_new_slice_window_set_icon (self, icon);
}

static void
____lambda59__gnome_pie_icon_select_window_on_ok (GnomePieIconSelectWindow* _sender,
                                                  const gchar* icon_name,
                                                  gpointer self)
{
	___lambda59_ ((GnomePieNewSliceWindow*) self, icon_name);
}

static void
gnome_pie_new_slice_window_on_icon_button_clicked (GnomePieNewSliceWindow* self,
                                                   GtkButton* button)
{
	GnomePieIconSelectWindow* _tmp0_;
	GnomePieIconSelectWindow* _tmp4_;
	GnomePieIconSelectWindow* _tmp5_;
	const gchar* _tmp6_;
	g_return_if_fail (self != NULL);
	g_return_if_fail (button != NULL);
	_tmp0_ = self->priv->icon_window;
	if (_tmp0_ == NULL) {
		GtkDialog* _tmp1_;
		GnomePieIconSelectWindow* _tmp2_;
		GnomePieIconSelectWindow* _tmp3_;
		_tmp1_ = self->priv->window;
		_tmp2_ = gnome_pie_icon_select_window_new ((GtkWindow*) _tmp1_);
		_g_object_unref0 (self->priv->icon_window);
		self->priv->icon_window = _tmp2_;
		_tmp3_ = self->priv->icon_window;
		g_signal_connect_object (_tmp3_, "on-ok", (GCallback) ____lambda59__gnome_pie_icon_select_window_on_ok, self, 0);
	}
	_tmp4_ = self->priv->icon_window;
	gnome_pie_icon_select_window_show (_tmp4_);
	_tmp5_ = self->priv->icon_window;
	_tmp6_ = self->priv->current_icon;
	gnome_pie_icon_select_window_set_icon (_tmp5_, _tmp6_);
}

static gboolean
string_contains (const gchar* self,
                 const gchar* needle)
{
	gchar* _tmp0_;
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	g_return_val_if_fail (needle != NULL, FALSE);
	_tmp0_ = strstr ((gchar*) self, (gchar*) needle);
	result = _tmp0_ != NULL;
	return result;
}

static void
gnome_pie_new_slice_window_set_icon (GnomePieNewSliceWindow* self,
                                     const gchar* icon)
{
	gchar* _tmp8_;
	GError* _inner_error0_ = NULL;
	g_return_if_fail (self != NULL);
	g_return_if_fail (icon != NULL);
	if (string_contains (icon, "/")) {
		{
			GdkPixbuf* _tmp0_ = NULL;
			GtkImage* _tmp1_;
			GtkImage* _tmp2_;
			GdkPixbuf* _tmp3_;
			GtkImage* _tmp4_;
			_tmp1_ = self->priv->icon;
			_tmp2_ = self->priv->icon;
			_tmp3_ = gdk_pixbuf_new_from_file_at_scale (icon, gtk_image_get_pixel_size (_tmp1_), gtk_image_get_pixel_size (_tmp2_), TRUE, &_inner_error0_);
			_tmp0_ = _tmp3_;
			if (G_UNLIKELY (_inner_error0_ != NULL)) {
				goto __catch0_g_error;
			}
			_tmp4_ = self->priv->icon;
			g_object_set (_tmp4_, "pixbuf", _tmp0_, NULL);
			_g_object_unref0 (_tmp0_);
		}
		goto __finally0;
		__catch0_g_error:
		{
			GError* _error_ = NULL;
			GError* _tmp5_;
			const gchar* _tmp6_;
			_error_ = _inner_error0_;
			_inner_error0_ = NULL;
			_tmp5_ = _error_;
			_tmp6_ = _tmp5_->message;
			g_warning ("newSliceWindow.vala:437: %s", _tmp6_);
			_g_error_free0 (_error_);
		}
		__finally0:
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
			g_clear_error (&_inner_error0_);
			return;
		}
	} else {
		GtkImage* _tmp7_;
		_tmp7_ = self->priv->icon;
		g_object_set (_tmp7_, "icon-name", icon, NULL);
	}
	_tmp8_ = g_strdup (icon);
	_g_free0 (self->priv->current_icon);
	self->priv->current_icon = _tmp8_;
}

static void
g_cclosure_user_marshal_VOID__OBJECT_BOOLEAN_INT (GClosure * closure,
                                                  GValue * return_value,
                                                  guint n_param_values,
                                                  const GValue * param_values,
                                                  gpointer invocation_hint,
                                                  gpointer marshal_data)
{
	typedef void (*GMarshalFunc_VOID__OBJECT_BOOLEAN_INT) (gpointer data1, gpointer arg_1, gboolean arg_2, gint arg_3, gpointer data2);
	register GMarshalFunc_VOID__OBJECT_BOOLEAN_INT callback;
	register GCClosure * cc;
	register gpointer data1;
	register gpointer data2;
	cc = (GCClosure *) closure;
	g_return_if_fail (n_param_values == 4);
	if (G_CCLOSURE_SWAP_DATA (closure)) {
		data1 = closure->data;
		data2 = param_values->data[0].v_pointer;
	} else {
		data1 = param_values->data[0].v_pointer;
		data2 = closure->data;
	}
	callback = (GMarshalFunc_VOID__OBJECT_BOOLEAN_INT) (marshal_data ? marshal_data : cc->callback);
	callback (data1, g_value_get_object (param_values + 1), g_value_get_boolean (param_values + 2), g_value_get_int (param_values + 3), data2);
}

static void
gnome_pie_new_slice_window_class_init (GnomePieNewSliceWindowClass * klass,
                                       gpointer klass_data)
{
	gnome_pie_new_slice_window_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &GnomePieNewSliceWindow_private_offset);
	G_OBJECT_CLASS (klass)->finalize = gnome_pie_new_slice_window_finalize;
	gnome_pie_new_slice_window_signals[GNOME_PIE_NEW_SLICE_WINDOW_ON_SELECT_SIGNAL] = g_signal_new ("on-select", GNOME_PIE_TYPE_NEW_SLICE_WINDOW, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__OBJECT_BOOLEAN_INT, G_TYPE_NONE, 3, GNOME_PIE_TYPE_ACTION_GROUP, G_TYPE_BOOLEAN, G_TYPE_INT);
}

static void
gnome_pie_new_slice_window_instance_init (GnomePieNewSliceWindow * self,
                                          gpointer klass)
{
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	self->priv = gnome_pie_new_slice_window_get_instance_private (self);
	self->priv->slice_type_list = NULL;
	self->priv->icon_window = NULL;
	self->priv->window = NULL;
	self->priv->name_box = NULL;
	self->priv->command_box = NULL;
	self->priv->icon_button = NULL;
	self->priv->no_options_box = NULL;
	self->priv->pie_box = NULL;
	self->priv->hotkey_box = NULL;
	self->priv->uri_box = NULL;
	self->priv->quickaction_box = NULL;
	self->priv->clipboard_box = NULL;
	self->priv->workspace_only_box = NULL;
	self->priv->icon = NULL;
	self->priv->name_entry = NULL;
	self->priv->command_list = NULL;
	self->priv->uri_entry = NULL;
	self->priv->quickaction_checkbutton = NULL;
	self->priv->workspace_only_checkbutton = NULL;
	self->priv->clipboard_slider = NULL;
	self->priv->pie_select = NULL;
	self->priv->key_select = NULL;
	_tmp0_ = g_strdup ("");
	self->priv->current_type = _tmp0_;
	_tmp1_ = g_strdup ("");
	self->priv->current_icon = _tmp1_;
	_tmp2_ = g_strdup ("");
	self->priv->current_id = _tmp2_;
	_tmp3_ = g_strdup ("");
	self->priv->current_custom_icon = _tmp3_;
	_tmp4_ = g_strdup ("");
	self->priv->current_hotkey = _tmp4_;
	_tmp5_ = g_strdup ("");
	self->priv->current_pie_to_open = _tmp5_;
	self->priv->slice_position = 0;
	self->priv->add_as_new_slice = TRUE;
}

static void
gnome_pie_new_slice_window_finalize (GObject * obj)
{
	GnomePieNewSliceWindow * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GNOME_PIE_TYPE_NEW_SLICE_WINDOW, GnomePieNewSliceWindow);
	_g_object_unref0 (self->priv->slice_type_list);
	_g_object_unref0 (self->priv->icon_window);
	_g_object_unref0 (self->priv->window);
	_g_object_unref0 (self->priv->name_box);
	_g_object_unref0 (self->priv->command_box);
	_g_object_unref0 (self->priv->icon_button);
	_g_object_unref0 (self->priv->no_options_box);
	_g_object_unref0 (self->priv->pie_box);
	_g_object_unref0 (self->priv->hotkey_box);
	_g_object_unref0 (self->priv->uri_box);
	_g_object_unref0 (self->priv->quickaction_box);
	_g_object_unref0 (self->priv->clipboard_box);
	_g_object_unref0 (self->priv->workspace_only_box);
	_g_object_unref0 (self->priv->icon);
	_g_object_unref0 (self->priv->name_entry);
	_g_object_unref0 (self->priv->command_list);
	_g_object_unref0 (self->priv->uri_entry);
	_g_object_unref0 (self->priv->quickaction_checkbutton);
	_g_object_unref0 (self->priv->workspace_only_checkbutton);
	_g_object_unref0 (self->priv->clipboard_slider);
	_g_object_unref0 (self->priv->pie_select);
	_g_object_unref0 (self->priv->key_select);
	_g_free0 (self->priv->current_type);
	_g_free0 (self->priv->current_icon);
	_g_free0 (self->priv->current_id);
	_g_free0 (self->priv->current_custom_icon);
	_g_free0 (self->priv->current_hotkey);
	_g_free0 (self->priv->current_pie_to_open);
	G_OBJECT_CLASS (gnome_pie_new_slice_window_parent_class)->finalize (obj);
}

static GType
gnome_pie_new_slice_window_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (GnomePieNewSliceWindowClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gnome_pie_new_slice_window_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GnomePieNewSliceWindow), 0, (GInstanceInitFunc) gnome_pie_new_slice_window_instance_init, NULL };
	GType gnome_pie_new_slice_window_type_id;
	gnome_pie_new_slice_window_type_id = g_type_register_static (G_TYPE_OBJECT, "GnomePieNewSliceWindow", &g_define_type_info, 0);
	GnomePieNewSliceWindow_private_offset = g_type_add_instance_private (gnome_pie_new_slice_window_type_id, sizeof (GnomePieNewSliceWindowPrivate));
	return gnome_pie_new_slice_window_type_id;
}

GType
gnome_pie_new_slice_window_get_type (void)
{
	static volatile gsize gnome_pie_new_slice_window_type_id__once = 0;
	if (g_once_init_enter (&gnome_pie_new_slice_window_type_id__once)) {
		GType gnome_pie_new_slice_window_type_id;
		gnome_pie_new_slice_window_type_id = gnome_pie_new_slice_window_get_type_once ();
		g_once_init_leave (&gnome_pie_new_slice_window_type_id__once, gnome_pie_new_slice_window_type_id);
	}
	return gnome_pie_new_slice_window_type_id__once;
}

